#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import questionnaire
from .fhirdate import FHIRDate


class QuestionnaireTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Questionnaire", js["resourceType"])
        return questionnaire.Questionnaire(js)
    
    def testQuestionnaire1(self):
        inst = self.instantiate_from("questionnaire-example-bluebook.json")
        self.assertIsNotNone(inst, "Must have instantiated a Questionnaire instance")
        self.implQuestionnaire1(inst)
        
        js = inst.as_json()
        self.assertEqual("Questionnaire", js["resourceType"])
        inst2 = questionnaire.Questionnaire(js)
        self.implQuestionnaire1(inst2)
    
    def implQuestionnaire1(self, inst):
        self.assertEqual(inst.date.date, FHIRDate("2013-02-19").date)
        self.assertEqual(inst.date.as_json(), "2013-02-19")
        self.assertEqual(inst.group.group[0].group[0].question[0].text, "Name of child")
        self.assertEqual(inst.group.group[0].group[0].question[1].text, "Sex")
        self.assertEqual(inst.group.group[0].group[1].question[0].text, "Birth weight (kg)")
        self.assertEqual(inst.group.group[0].group[1].question[1].text, "Birth length (cm)")
        self.assertEqual(inst.group.group[0].group[1].question[2].group[0].extension[0].url, "http://example.org/Profile/questionnaire#visibilityCondition")
        self.assertEqual(inst.group.group[0].group[1].question[2].group[0].extension[0].valueString, "HAS_VALUE(../choice/code) AND NEQ(../choice/code,'NO')")
        self.assertEqual(inst.group.group[0].group[1].question[2].group[0].question[0].text, "1st dose")
        self.assertEqual(inst.group.group[0].group[1].question[2].group[0].question[1].text, "2nd dose")
        self.assertEqual(inst.group.group[0].group[1].question[2].text, "Vitamin K given")
        self.assertEqual(inst.group.group[0].group[1].question[3].group[0].question[0].text, "Date given")
        self.assertEqual(inst.group.group[0].group[1].question[3].text, "Hep B given y / n")
        self.assertEqual(inst.group.group[0].group[1].question[4].text, "Abnormalities noted at birth")
        self.assertEqual(inst.group.group[0].group[1].title, "Neonatal Information")
        self.assertEqual(inst.group.group[0].title, "Birth details - To be completed by health professional")
        self.assertEqual(inst.group.title, "NSW Government My Personal Health Record")
        self.assertEqual(inst.id, "bb")
        self.assertEqual(inst.publisher, "New South Wales Department of Health")
        self.assertEqual(inst.status, "draft")
        self.assertEqual(inst.text.status, "generated")
    
    def testQuestionnaire2(self):
        inst = self.instantiate_from("questionnaire-example-f201-lifelines.json")
        self.assertIsNotNone(inst, "Must have instantiated a Questionnaire instance")
        self.implQuestionnaire2(inst)
        
        js = inst.as_json()
        self.assertEqual("Questionnaire", js["resourceType"])
        inst2 = questionnaire.Questionnaire(js)
        self.implQuestionnaire2(inst2)
    
    def implQuestionnaire2(self, inst):
        self.assertEqual(inst.date.date, FHIRDate("2010").date)
        self.assertEqual(inst.date.as_json(), "2010")
        self.assertEqual(inst.group.concept[0].code, "VL 1-1, 18-65_1.2.2")
        self.assertEqual(inst.group.concept[0].display, "Lifelines Questionnaire 1 part 1")
        self.assertEqual(inst.group.concept[0].system, "http://example.org/system/code/lifelines/nl")
        self.assertEqual(inst.group.group[0].question[0].text, "Do you have allergies?")
        self.assertEqual(inst.group.group[1].question[0].text, "What is your gender?")
        self.assertEqual(inst.group.group[1].question[1].text, "What is your date of birth?")
        self.assertEqual(inst.group.group[1].question[2].text, "What is your country of birth?")
        self.assertEqual(inst.group.group[1].question[3].text, "What is your marital status?")
        self.assertEqual(inst.group.group[1].text, "General questions")
        self.assertEqual(inst.group.group[2].question[0].text, "Do you smoke?")
        self.assertEqual(inst.group.group[2].question[1].text, "Do you drink alchohol?")
        self.assertEqual(inst.group.group[2].title, "Intoxications")
        self.assertEqual(inst.id, "f201")
        self.assertEqual(inst.status, "published")
        self.assertEqual(inst.text.status, "generated")
    
    def testQuestionnaire3(self):
        inst = self.instantiate_from("questionnaire-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Questionnaire instance")
        self.implQuestionnaire3(inst)
        
        js = inst.as_json()
        self.assertEqual("Questionnaire", js["resourceType"])
        inst2 = questionnaire.Questionnaire(js)
        self.implQuestionnaire3(inst2)
    
    def implQuestionnaire3(self, inst):
        self.assertEqual(inst.date.date, FHIRDate("2012-01").date)
        self.assertEqual(inst.date.as_json(), "2012-01")
        self.assertEqual(inst.group.group[0].concept[0].code, "COMORBIDITY")
        self.assertEqual(inst.group.group[0].concept[0].system, "http://example.org/system/code/sections")
        self.assertEqual(inst.group.group[0].question[0].concept[0].code, "COMORB")
        self.assertEqual(inst.group.group[0].question[0].concept[0].system, "http://example.org/system/code/questions")
        self.assertEqual(inst.group.group[0].question[0].group[0].concept[0].code, "CARDIAL")
        self.assertEqual(inst.group.group[0].question[0].group[0].concept[0].system, "http://example.org/system/code/sections")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[0].concept[0].code, "COMORBCAR")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[0].concept[0].system, "http://example.org/system/code/questions")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[0].type, "choice")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[1].concept[0].code, "COMCAR00")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[1].concept[0].display, "Angina Pectoris")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[1].concept[0].system, "http://example.org/system/code/questions")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[1].concept[1].code, "194828000")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[1].concept[1].display, "Angina (disorder)")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[1].concept[1].system, "http://snomed.info/sct")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[1].type, "choice")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[2].concept[0].code, "22298006")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[2].concept[0].display, "Myocardial infarction (disorder)")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[2].concept[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.group.group[0].question[0].group[0].question[2].type, "choice")
        self.assertEqual(inst.group.group[0].question[0].group[1].concept[0].code, "VASCULAR")
        self.assertEqual(inst.group.group[0].question[0].group[1].concept[0].system, "http://example.org/system/code/sections")
        self.assertEqual(inst.group.group[0].question[0].type, "choice")
        self.assertEqual(inst.group.group[1].concept[0].code, "HISTOPATHOLOGY")
        self.assertEqual(inst.group.group[1].concept[0].system, "http://example.org/system/code/sections")
        self.assertEqual(inst.group.group[1].group[0].concept[0].code, "ABDOMINAL")
        self.assertEqual(inst.group.group[1].group[0].concept[0].system, "http://example.org/system/code/sections")
        self.assertEqual(inst.group.group[1].group[0].question[0].concept[0].code, "STADPT")
        self.assertEqual(inst.group.group[1].group[0].question[0].concept[0].display, "pT category")
        self.assertEqual(inst.group.group[1].group[0].question[0].concept[0].system, "http://example.org/system/code/questions")
        self.assertEqual(inst.group.title, "Cancer Quality Forum Questionnaire 2012")
        self.assertEqual(inst.id, "3141")
        self.assertEqual(inst.status, "draft")
        self.assertEqual(inst.text.status, "generated")
    
    def testQuestionnaire4(self):
        inst = self.instantiate_from("questionnaire-sdc-profile-example-LOINC.json")
        self.assertIsNotNone(inst, "Must have instantiated a Questionnaire instance")
        self.implQuestionnaire4(inst)
        
        js = inst.as_json()
        self.assertEqual("Questionnaire", js["resourceType"])
        inst2 = questionnaire.Questionnaire(js)
        self.implQuestionnaire4(inst2)
    
    def implQuestionnaire4(self, inst):
        self.assertEqual(inst.date.date, FHIRDate("2012-04-01").date)
        self.assertEqual(inst.date.as_json(), "2012-04-01")
        self.assertEqual(inst.extension[0].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-category")
        self.assertEqual(inst.extension[0].valueCodeableConcept.coding[0].code, "Acute Care Hospitals")
        self.assertEqual(inst.group.group[0].extension[0].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-sdc-specialGroup")
        self.assertEqual(inst.group.group[0].extension[0].valueCode, "header")
        self.assertEqual(inst.group.group[0].linkId, "Medication/header")
        self.assertEqual(inst.group.group[0].question[0].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[0].question[0].extension[0].valueInteger, 3)
        self.assertEqual(inst.group.group[0].question[0].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[0].question[0].extension[1].valueInteger, 9)
        self.assertEqual(inst.group.group[0].question[0].linkId, "74080-3/74081-1")
        self.assertTrue(inst.group.group[0].question[0].required)
        self.assertEqual(inst.group.group[0].question[0].text, "Event ID:")
        self.assertEqual(inst.group.group[0].question[0].type, "string")
        self.assertEqual(inst.group.group[0].question[1].linkId, "74080-3/30947-6")
        self.assertTrue(inst.group.group[0].question[1].required)
        self.assertEqual(inst.group.group[0].question[1].text, "Initial Report Date (HERF Q1)")
        self.assertEqual(inst.group.group[0].question[1].type, "string")
        self.assertEqual(inst.group.group[1].group[0].linkId, "Medication/SEC01/74080-3")
        self.assertEqual(inst.group.group[1].group[0].question[0].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[0].question[0].extension[0].valueInteger, 1)
        self.assertEqual(inst.group.group[1].group[0].question[0].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[0].question[0].extension[1].valueInteger, 30)
        self.assertEqual(inst.group.group[1].group[0].question[0].extension[2].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-deReference")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].linkId, "74080-3/74076-1/LA20271-5")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].extension[0].valueInteger, 7)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].extension[1].valueInteger, 65)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].extension[2].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-deReference")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].linkId, "74080-3/74077-9")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].question[0].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].question[0].extension[0].valueInteger, 0)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].question[0].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].question[0].extension[1].valueInteger, 500)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].question[0].extension[2].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-deReference")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].question[0].linkId, "74080-3/74077-9-q")
        self.assertTrue(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].question[0].repeats)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].question[0].text, "Please list all ingredients:")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].question[0].type, "string")
        self.assertFalse(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[0].group[0].question[0].group[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].linkId, "74080-3/74075-3")
        self.assertTrue(inst.group.group[1].group[0].question[0].group[0].question[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].text, "What type of medication?")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[0].question[0].type, "open-choice")
        self.assertFalse(inst.group.group[1].group[0].question[0].group[0].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[0].group[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].linkId, "74080-3/74076-1/LA20335-8")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].question[0].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].question[0].extension[0].valueInteger, 8)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].question[0].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].question[0].extension[1].valueInteger, 65)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].question[0].group[0].linkId, "74080-3/74074-6/LA20283-0")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].question[0].group[0].question[0].linkId, "74080-3/30959-1")
        self.assertTrue(inst.group.group[1].group[0].question[0].group[1].question[0].group[0].question[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].question[0].group[0].question[0].text, "What was the lot number of the vaccine?")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].question[0].group[0].question[0].type, "string")
        self.assertFalse(inst.group.group[1].group[0].question[0].group[1].question[0].group[0].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[0].group[1].question[0].group[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].question[0].linkId, "74080-3/74074-6")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].question[0].text, "What type of biological product?")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[1].question[0].type, "open-choice")
        self.assertFalse(inst.group.group[1].group[0].question[0].group[1].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[0].group[1].required)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[2].linkId, "74080-3/74076-1/LA20336-6")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[2].question[0].linkId, "74080-3/74073-8")
        self.assertTrue(inst.group.group[1].group[0].question[0].group[2].question[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[0].group[2].question[0].text, "What type of nutritional product?")
        self.assertEqual(inst.group.group[1].group[0].question[0].group[2].question[0].type, "open-choice")
        self.assertFalse(inst.group.group[1].group[0].question[0].group[2].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[0].group[2].required)
        self.assertEqual(inst.group.group[1].group[0].question[0].linkId, "74080-3/74076-1")
        self.assertTrue(inst.group.group[1].group[0].question[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[0].text, "What type of medication/substance was involved?")
        self.assertEqual(inst.group.group[1].group[0].question[0].type, "open-choice")
        self.assertEqual(inst.group.group[1].group[0].question[1].linkId, "74080-3/74072-0")
        self.assertTrue(inst.group.group[1].group[0].question[1].required)
        self.assertEqual(inst.group.group[1].group[0].question[1].text, "Which of the following best characterizes the event?")
        self.assertEqual(inst.group.group[1].group[0].question[1].type, "open-choice")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[0].linkId, "74080-3/74071-2/A1275")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[0].question[0].linkId, "74080-3/74070-4")
        self.assertTrue(inst.group.group[1].group[0].question[2].group[0].question[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[0].question[0].text, "Which best describes the incorrect dose(s)?")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[0].question[0].type, "open-choice")
        self.assertFalse(inst.group.group[1].group[0].question[2].group[0].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[2].group[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[1].linkId, "74080-3/74071-2/LA20313-5")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[1].question[0].linkId, "Medication/74069-6")
        self.assertTrue(inst.group.group[1].group[0].question[2].group[1].question[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[1].question[0].text, "Which best describes the incorrect timing?")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[1].question[0].type, "open-choice")
        self.assertFalse(inst.group.group[1].group[0].question[2].group[1].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[2].group[1].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[2].linkId, "74080-3/74071-2/LA20306-9")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[2].question[0].linkId, "74080-3/74068-8")
        self.assertTrue(inst.group.group[1].group[0].question[2].group[2].question[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[2].question[0].text, "Which best describes the incorrect rate?")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[2].question[0].type, "open-choice")
        self.assertFalse(inst.group.group[1].group[0].question[2].group[2].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[2].group[2].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[3].linkId, "74080-3/74071-2/LA20309-3")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[3].question[0].linkId, "Medication/74067-0")
        self.assertTrue(inst.group.group[1].group[0].question[2].group[3].question[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[3].question[0].text, "Which best describes the incorrect strength or concentration?")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[3].question[0].type, "open-choice")
        self.assertFalse(inst.group.group[1].group[0].question[2].group[3].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[2].group[3].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[4].linkId, "74080-3/74071-2/LA20311-9")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[4].question[0].linkId, "Medication/74066-2")
        self.assertTrue(inst.group.group[1].group[0].question[2].group[4].question[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[4].question[0].text, "What was the expiration date?")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[4].question[0].type, "string")
        self.assertFalse(inst.group.group[1].group[0].question[2].group[4].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[2].group[4].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[5].linkId, "74080-3/74071-2/LA20312-7")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[5].question[0].linkId, "Medication/74065-4")
        self.assertTrue(inst.group.group[1].group[0].question[2].group[5].question[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[5].question[0].text, "Was there a documented history of allergies or sensitivities to the medication/substance                      administered?")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[5].question[0].type, "open-choice")
        self.assertFalse(inst.group.group[1].group[0].question[2].group[5].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[2].group[5].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[6].linkId, "74080-3/74071-2/LA20345-7")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[6].question[0].linkId, "Medication/74064-7")
        self.assertTrue(inst.group.group[1].group[0].question[2].group[6].question[0].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].group[6].question[0].text, "What was the contraindication (potential or actual interaction)?")
        self.assertEqual(inst.group.group[1].group[0].question[2].group[6].question[0].type, "open-choice")
        self.assertFalse(inst.group.group[1].group[0].question[2].group[6].repeats)
        self.assertFalse(inst.group.group[1].group[0].question[2].group[6].required)
        self.assertEqual(inst.group.group[1].group[0].question[2].linkId, "74080-3/74071-2")
        self.assertEqual(inst.group.group[1].group[0].question[2].text, "What was the incorrect action?")
        self.assertEqual(inst.group.group[1].group[0].question[2].type, "open-choice")
        self.assertEqual(inst.group.group[1].group[0].question[3].linkId, "74080-3/74063-9")
        self.assertTrue(inst.group.group[1].group[0].question[3].required)
        self.assertEqual(inst.group.group[1].group[0].question[3].text, "At what stage in the process did the event originate, regardless of the stage at which                  it was discovered?")
        self.assertEqual(inst.group.group[1].group[0].question[3].type, "open-choice")
        self.assertTrue(inst.group.group[1].group[0].required)
        self.assertEqual(inst.group.group[1].group[1].extension[0].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxOccurs")
        self.assertEqual(inst.group.group[1].group[1].extension[0].valueInteger, 5)
        self.assertEqual(inst.group.group[1].group[1].linkId, "74080-3/74078-7")
        self.assertEqual(inst.group.group[1].group[1].question[0].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[1].question[0].extension[0].valueInteger, 0)
        self.assertEqual(inst.group.group[1].group[1].question[0].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[1].question[0].extension[1].valueInteger, 65)
        self.assertEqual(inst.group.group[1].group[1].question[0].linkId, "74080-3/74078-7/74062-1")
        self.assertEqual(inst.group.group[1].group[1].question[0].text, "Generic name or investigational drug name")
        self.assertEqual(inst.group.group[1].group[1].question[0].type, "string")
        self.assertEqual(inst.group.group[1].group[1].question[1].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[1].question[1].extension[0].valueInteger, 0)
        self.assertEqual(inst.group.group[1].group[1].question[1].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[1].question[1].extension[1].valueInteger, 65)
        self.assertEqual(inst.group.group[1].group[1].question[1].linkId, "74080-3/74078-7/74061-3")
        self.assertEqual(inst.group.group[1].group[1].question[1].text, "Ingredient RXCUI (if known)")
        self.assertEqual(inst.group.group[1].group[1].question[1].type, "string")
        self.assertEqual(inst.group.group[1].group[1].question[2].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[1].question[2].extension[0].valueInteger, 0)
        self.assertEqual(inst.group.group[1].group[1].question[2].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[1].question[2].extension[1].valueInteger, 65)
        self.assertEqual(inst.group.group[1].group[1].question[2].linkId, "74080-3/74078-7/74060-5")
        self.assertEqual(inst.group.group[1].group[1].question[2].text, "Brand name (if known)")
        self.assertEqual(inst.group.group[1].group[1].question[2].type, "string")
        self.assertEqual(inst.group.group[1].group[1].question[3].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[1].question[3].extension[0].valueInteger, 0)
        self.assertEqual(inst.group.group[1].group[1].question[3].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[1].question[3].extension[1].valueInteger, 65)
        self.assertEqual(inst.group.group[1].group[1].question[3].linkId, "74080-3/74078-7/74059-7")
        self.assertEqual(inst.group.group[1].group[1].question[3].text, "Brand name RXCUI (if known)")
        self.assertEqual(inst.group.group[1].group[1].question[3].type, "string")
        self.assertEqual(inst.group.group[1].group[1].question[4].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[1].question[4].extension[0].valueInteger, 0)
        self.assertEqual(inst.group.group[1].group[1].question[4].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[1].question[4].extension[1].valueInteger, 65)
        self.assertEqual(inst.group.group[1].group[1].question[4].linkId, "74080-3/74078-7/74058-9")
        self.assertEqual(inst.group.group[1].group[1].question[4].text, "Manufacturer (if known)")
        self.assertEqual(inst.group.group[1].group[1].question[4].type, "string")
        self.assertEqual(inst.group.group[1].group[1].question[5].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[1].question[5].extension[0].valueInteger, 0)
        self.assertEqual(inst.group.group[1].group[1].question[5].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[1].question[5].extension[1].valueInteger, 65)
        self.assertEqual(inst.group.group[1].group[1].question[5].linkId, "74080-3/74078-7/74057-1")
        self.assertEqual(inst.group.group[1].group[1].question[5].text, "Strength or concentration of product")
        self.assertEqual(inst.group.group[1].group[1].question[5].type, "string")
        self.assertEqual(inst.group.group[1].group[1].question[6].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[1].question[6].extension[0].valueInteger, 0)
        self.assertEqual(inst.group.group[1].group[1].question[6].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[1].question[6].extension[1].valueInteger, 65)
        self.assertEqual(inst.group.group[1].group[1].question[6].linkId, "74080-3/74078-7/74056-3")
        self.assertEqual(inst.group.group[1].group[1].question[6].text, "Clinical drug component RXCUI (if known)")
        self.assertEqual(inst.group.group[1].group[1].question[6].type, "string")
        self.assertEqual(inst.group.group[1].group[1].question[7].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[1].question[7].extension[0].valueInteger, 0)
        self.assertEqual(inst.group.group[1].group[1].question[7].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[1].question[7].extension[1].valueInteger, 65)
        self.assertEqual(inst.group.group[1].group[1].question[7].linkId, "74080-3/74078-7/74055-5")
        self.assertEqual(inst.group.group[1].group[1].question[7].text, "Dosage form of Product")
        self.assertEqual(inst.group.group[1].group[1].question[7].type, "string")
        self.assertEqual(inst.group.group[1].group[1].question[8].extension[0].url, "http://hl7.org/fhir/StructureDefinition/minLength")
        self.assertEqual(inst.group.group[1].group[1].question[8].extension[0].valueInteger, 0)
        self.assertEqual(inst.group.group[1].group[1].question[8].extension[1].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-maxLength")
        self.assertEqual(inst.group.group[1].group[1].question[8].extension[1].valueInteger, 65)
        self.assertEqual(inst.group.group[1].group[1].question[8].linkId, "74080-3/74078-7/74054-8")
        self.assertEqual(inst.group.group[1].group[1].question[8].text, "Dose form RXCUI (if known)")
        self.assertEqual(inst.group.group[1].group[1].question[8].type, "string")
        self.assertEqual(inst.group.group[1].group[1].question[9].linkId, "74080-3/74078-7/74053-0")
        self.assertTrue(inst.group.group[1].group[1].question[9].required)
        self.assertEqual(inst.group.group[1].group[1].question[9].text, "Was this medication/substance prescribed for this patient?")
        self.assertEqual(inst.group.group[1].group[1].question[9].type, "open-choice")
        self.assertTrue(inst.group.group[1].group[1].repeats)
        self.assertEqual(inst.group.group[1].group[1].text, "Please provide the following medication details for any medications or other substances                directly involved in the event.")
        self.assertEqual(inst.group.group[1].group[2].linkId, "Medication/SEC03")
        self.assertEqual(inst.group.group[1].group[2].question[0].linkId, "74080-3/74051-4")
        self.assertTrue(inst.group.group[1].group[2].question[0].required)
        self.assertEqual(inst.group.group[1].group[2].question[0].text, "What was the intended route of administration?")
        self.assertEqual(inst.group.group[1].group[2].question[0].type, "open-choice")
        self.assertEqual(inst.group.group[1].group[2].question[1].linkId, "74080-3/74050-6")
        self.assertTrue(inst.group.group[1].group[2].question[1].required)
        self.assertEqual(inst.group.group[1].group[2].question[1].text, "What was the actual route of administration (attempted or completed)?")
        self.assertEqual(inst.group.group[1].group[2].question[1].type, "open-choice")
        self.assertEqual(inst.group.group[1].group[3].linkId, "Medication/SEC04")
        self.assertEqual(inst.group.group[1].group[3].text, "The form is complete.")
        self.assertEqual(inst.group.group[1].group[3].title, "STOP")
        self.assertEqual(inst.group.group[1].group[4].linkId, "Medication/SEC05")
        self.assertEqual(inst.group.group[1].group[4].title, "Thank you for completing these questions.")
        self.assertEqual(inst.group.group[1].linkId, "Medication/SEC00")
        self.assertEqual(inst.group.group[1].title, "Medication or Other Substance")
        self.assertEqual(inst.group.group[2].extension[0].url, "http://hl7.org/fhir/StructureDefinition/questionnaire-sdc-specialGroup")
        self.assertEqual(inst.group.group[2].extension[0].valueCode, "footer")
        self.assertEqual(inst.group.group[2].linkId, "Medication/footer")
        self.assertEqual(inst.group.group[2].text, "AHRQ Common Formats - Hospital Version 1.2 - 2012 Medication or Other Substance")
        self.assertEqual(inst.group.linkId, "root")
        self.assertEqual(inst.group.title, "Medication or Other Substance")
        self.assertEqual(inst.id, "sdc-loinc")
        self.assertEqual(inst.identifier[0].system, "http://loinc.org/vs")
        self.assertEqual(inst.identifier[0].value, "74080-3")
        self.assertEqual(inst.publisher, "Agency for Healthcare Research and Quality (AHRQ)")
        self.assertEqual(inst.status, "published")
        self.assertEqual(inst.text.div, "<div>Todo</div>")
        self.assertEqual(inst.text.status, "generated")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import nutritionorder
from .fhirdate import FHIRDate


class NutritionOrderTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("NutritionOrder", js["resourceType"])
        return nutritionorder.NutritionOrder(js)
    
    def testNutritionOrder1(self):
        inst = self.instantiate_from("nutritionorder-example-cardiacdiet.json")
        self.assertIsNotNone(inst, "Must have instantiated a NutritionOrder instance")
        self.implNutritionOrder1(inst)
        
        js = inst.as_json()
        self.assertEqual("NutritionOrder", js["resourceType"])
        inst2 = nutritionorder.NutritionOrder(js)
        self.implNutritionOrder1(inst2)
    
    def implNutritionOrder1(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.dateTime.as_json(), "2014-09-17")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].code, "227493005")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].display, "Cashew Nut")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].version, "20140730")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].code, "dairy-free")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].system, "http://hl7.org/fhir/diet")
        self.assertEqual(inst.id, "cardiacdiet")
        self.assertEqual(inst.identifier[0].system, "http://goodhealthhospital.org/nutrition-orders")
        self.assertEqual(inst.identifier[0].value, "123")
        self.assertEqual(inst.oralDiet.instruction, "Starting on 2/10 breakfast, maximum 400 ml fluids per meal")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.code, "g")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.units, "grams")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.value, 2)
        self.assertEqual(inst.oralDiet.nutrient[0].mod.coding[0].code, "39972003")
        self.assertEqual(inst.oralDiet.nutrient[0].mod.coding[0].display, "Sodium")
        self.assertEqual(inst.oralDiet.nutrient[0].mod.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.nutrient[1].amount.code, "mL")
        self.assertEqual(inst.oralDiet.nutrient[1].amount.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.oralDiet.nutrient[1].amount.units, "milliliter")
        self.assertEqual(inst.oralDiet.nutrient[1].amount.value, 1500)
        self.assertEqual(inst.oralDiet.nutrient[1].mod.coding[0].code, "33463005")
        self.assertEqual(inst.oralDiet.nutrient[1].mod.coding[0].display, "Fluid")
        self.assertEqual(inst.oralDiet.nutrient[1].mod.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.type[0].coding[0].code, "386619000")
        self.assertEqual(inst.oralDiet.type[0].coding[0].display, "Low sodium diet")
        self.assertEqual(inst.oralDiet.type[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.type[0].coding[1].code, "1040")
        self.assertEqual(inst.oralDiet.type[0].coding[1].display, "Low Sodium Diet")
        self.assertEqual(inst.oralDiet.type[0].coding[1].system, "http://goodhealthhospital.org/diet-type-codes")
        self.assertEqual(inst.oralDiet.type[0].text, "Low sodium diet")
        self.assertEqual(inst.oralDiet.type[1].coding[0].code, "226208002")
        self.assertEqual(inst.oralDiet.type[1].coding[0].display, "Fluid restricted diet")
        self.assertEqual(inst.oralDiet.type[1].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.type[1].coding[1].code, "1040")
        self.assertEqual(inst.oralDiet.type[1].coding[1].display, "Fluid restricted diet")
        self.assertEqual(inst.oralDiet.type[1].coding[1].system, "http://goodhealthhospital.org/diet-type-codes")
        self.assertEqual(inst.oralDiet.type[1].text, "Fluid restricted diet")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.status, "generated")
    
    def testNutritionOrder2(self):
        inst = self.instantiate_from("nutritionorder-example-diabeticdiet.json")
        self.assertIsNotNone(inst, "Must have instantiated a NutritionOrder instance")
        self.implNutritionOrder2(inst)
        
        js = inst.as_json()
        self.assertEqual("NutritionOrder", js["resourceType"])
        inst2 = nutritionorder.NutritionOrder(js)
        self.implNutritionOrder2(inst2)
    
    def implNutritionOrder2(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.dateTime.as_json(), "2014-09-17")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].code, "227493005")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].display, "Cashew Nut")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].version, "20140730")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].code, "dairy-free")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].system, "http://hl7.org/fhir/diet")
        self.assertEqual(inst.id, "diabeticdiet")
        self.assertEqual(inst.identifier[0].system, "http://goodhealthhospital.org/nutrition-orders")
        self.assertEqual(inst.identifier[0].value, "123")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.code, "g")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.units, "grams")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.value, 75)
        self.assertEqual(inst.oralDiet.nutrient[0].mod.coding[0].code, "2331003")
        self.assertEqual(inst.oralDiet.nutrient[0].mod.coding[0].display, "Carbohydrate")
        self.assertEqual(inst.oralDiet.nutrient[0].mod.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.scheduled.repeat.bounds.start.date, FHIRDate("2015-02-10").date)
        self.assertEqual(inst.oralDiet.scheduled.repeat.bounds.start.as_json(), "2015-02-10")
        self.assertEqual(inst.oralDiet.scheduled.repeat.frequency, 3)
        self.assertEqual(inst.oralDiet.scheduled.repeat.period, 1)
        self.assertEqual(inst.oralDiet.scheduled.repeat.periodUnits, "d")
        self.assertEqual(inst.oralDiet.type[0].coding[0].code, "160670007")
        self.assertEqual(inst.oralDiet.type[0].coding[0].display, "Diabetic diet")
        self.assertEqual(inst.oralDiet.type[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.type[0].coding[1].code, "1030")
        self.assertEqual(inst.oralDiet.type[0].coding[1].display, "DD - Diabetic diet")
        self.assertEqual(inst.oralDiet.type[0].coding[1].system, "http://goodhealthhospital.org/diet-type-codes")
        self.assertEqual(inst.oralDiet.type[0].text, "DD - Diabetic diet")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.status, "generated")
    
    def testNutritionOrder3(self):
        inst = self.instantiate_from("nutritionorder-example-diabeticsupplement.json")
        self.assertIsNotNone(inst, "Must have instantiated a NutritionOrder instance")
        self.implNutritionOrder3(inst)
        
        js = inst.as_json()
        self.assertEqual("NutritionOrder", js["resourceType"])
        inst2 = nutritionorder.NutritionOrder(js)
        self.implNutritionOrder3(inst2)
    
    def implNutritionOrder3(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.dateTime.as_json(), "2014-09-17")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].code, "227493005")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].display, "Cashew Nut")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].version, "20140730")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].code, "kosher")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].system, "http://hl7.org/fhir/diet")
        self.assertEqual(inst.id, "diabeticsupplement")
        self.assertEqual(inst.identifier[0].system, "http://goodhealthhospital.org/nutrition-orders")
        self.assertEqual(inst.identifier[0].value, "123")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.supplement[0].productName, "Glucerna")
        self.assertEqual(inst.supplement[0].quantity.units, "8 oz bottle")
        self.assertEqual(inst.supplement[0].quantity.value, 1)
        self.assertEqual(inst.supplement[0].scheduled.repeat.bounds.start.date, FHIRDate("2015-02-10").date)
        self.assertEqual(inst.supplement[0].scheduled.repeat.bounds.start.as_json(), "2015-02-10")
        self.assertEqual(inst.supplement[0].scheduled.repeat.period, 1)
        self.assertEqual(inst.supplement[0].scheduled.repeat.periodUnits, "h")
        self.assertEqual(inst.supplement[0].scheduled.repeat.when, "HS")
        self.assertEqual(inst.supplement[0].type.coding[0].code, "443051000124104")
        self.assertEqual(inst.supplement[0].type.coding[0].display, "Adult diabetes specialty formula")
        self.assertEqual(inst.supplement[0].type.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.supplement[0].type.coding[1].code, "1010")
        self.assertEqual(inst.supplement[0].type.coding[1].display, "Adult diabetic formula")
        self.assertEqual(inst.supplement[0].type.coding[1].system, "http://goodhealthhospital.org/supplement-type-codes")
        self.assertEqual(inst.supplement[0].type.text, "Adult diabetic formula")
        self.assertEqual(inst.text.status, "generated")
    
    def testNutritionOrder4(self):
        inst = self.instantiate_from("nutritionorder-example-energysupplement.json")
        self.assertIsNotNone(inst, "Must have instantiated a NutritionOrder instance")
        self.implNutritionOrder4(inst)
        
        js = inst.as_json()
        self.assertEqual("NutritionOrder", js["resourceType"])
        inst2 = nutritionorder.NutritionOrder(js)
        self.implNutritionOrder4(inst2)
    
    def implNutritionOrder4(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.dateTime.as_json(), "2014-09-17")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].code, "227493005")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].display, "Cashew Nut")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].version, "20140730")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].code, "kosher")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].system, "http://hl7.org/fhir/diet")
        self.assertEqual(inst.id, "energysupplement")
        self.assertEqual(inst.identifier[0].system, "http://goodhealthhospital.org/nutrition-orders")
        self.assertEqual(inst.identifier[0].value, "123")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.supplement[0].productName, "Ensure")
        self.assertEqual(inst.supplement[0].quantity.units, "8 oz can")
        self.assertEqual(inst.supplement[0].quantity.value, 1)
        self.assertEqual(inst.supplement[0].scheduled.repeat.bounds.start.date, FHIRDate("2015-02-10").date)
        self.assertEqual(inst.supplement[0].scheduled.repeat.bounds.start.as_json(), "2015-02-10")
        self.assertEqual(inst.supplement[0].scheduled.repeat.frequency, 3)
        self.assertEqual(inst.supplement[0].scheduled.repeat.period, 1)
        self.assertEqual(inst.supplement[0].scheduled.repeat.periodUnits, "d")
        self.assertEqual(inst.supplement[0].type.coding[0].code, "442971000124100")
        self.assertEqual(inst.supplement[0].type.coding[0].display, "Adult high energy formula")
        self.assertEqual(inst.supplement[0].type.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.supplement[0].type.coding[1].code, "1010")
        self.assertEqual(inst.supplement[0].type.coding[1].display, "Adult high energy drink")
        self.assertEqual(inst.supplement[0].type.coding[1].system, "http://goodhealthhospital.org/supplement-type-codes")
        self.assertEqual(inst.supplement[0].type.text, "Adult high energy drink")
        self.assertEqual(inst.text.status, "generated")
    
    def testNutritionOrder5(self):
        inst = self.instantiate_from("nutritionorder-example-enteralbolus.json")
        self.assertIsNotNone(inst, "Must have instantiated a NutritionOrder instance")
        self.implNutritionOrder5(inst)
        
        js = inst.as_json()
        self.assertEqual("NutritionOrder", js["resourceType"])
        inst2 = nutritionorder.NutritionOrder(js)
        self.implNutritionOrder5(inst2)
    
    def implNutritionOrder5(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.dateTime.as_json(), "2014-09-17")
        self.assertEqual(inst.enteralFormula.additiveProductName, "Acme Lipid Additive")
        self.assertEqual(inst.enteralFormula.additiveType.coding[0].code, "lipid")
        self.assertEqual(inst.enteralFormula.additiveType.coding[0].display, "Modular lipid enteral formula component")
        self.assertEqual(inst.enteralFormula.additiveType.coding[0].system, "http://hl7.org/fhir/entformula-additive")
        self.assertEqual(inst.enteralFormula.administrationInstructions, "240 mls every 4hrs ")
        self.assertEqual(inst.enteralFormula.baseFormulaProductName, "Acme High Protein Formula")
        self.assertEqual(inst.enteralFormula.baseFormulaType.coding[0].code, "659311000124118")
        self.assertEqual(inst.enteralFormula.baseFormulaType.coding[0].display, "Adult high protein formula")
        self.assertEqual(inst.enteralFormula.baseFormulaType.coding[0].system, "http://usextension/snomed.info/sct")
        self.assertEqual(inst.enteralFormula.caloricDensity.code, "cal/mL")
        self.assertEqual(inst.enteralFormula.caloricDensity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.enteralFormula.caloricDensity.units, "calories per milliliter")
        self.assertEqual(inst.enteralFormula.caloricDensity.value, 1.5)
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.code, "mL/d")
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.units, "milliliter/day")
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.value, 1440)
        self.assertEqual(inst.enteralFormula.quantity.code, "mL")
        self.assertEqual(inst.enteralFormula.quantity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.enteralFormula.quantity.units, "milliliters")
        self.assertEqual(inst.enteralFormula.quantity.value, 240)
        self.assertEqual(inst.enteralFormula.routeofAdministration.coding[0].code, "GT")
        self.assertEqual(inst.enteralFormula.routeofAdministration.coding[0].display, "Instillation, gastrostomy tube")
        self.assertEqual(inst.enteralFormula.routeofAdministration.coding[0].system, "http://hl7.org/fhir/v3/RouteOfAdministration")
        self.assertEqual(inst.enteralFormula.scheduled.repeat.bounds.start.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.enteralFormula.scheduled.repeat.bounds.start.as_json(), "2014-09-17")
        self.assertEqual(inst.enteralFormula.scheduled.repeat.frequency, 1)
        self.assertEqual(inst.enteralFormula.scheduled.repeat.period, 4)
        self.assertEqual(inst.enteralFormula.scheduled.repeat.periodUnits, "h")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].code, "227493005")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].display, "Cashew Nut")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].version, "20140730")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].code, "dairy-free")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].system, "http://hl7.org/fhir/diet")
        self.assertEqual(inst.id, "enteralbolus")
        self.assertEqual(inst.identifier[0].system, "http://www.acme.org/nutritionorders")
        self.assertEqual(inst.identifier[0].value, "123")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.status, "generated")
    
    def testNutritionOrder6(self):
        inst = self.instantiate_from("nutritionorder-example-enteralcontinuous.json")
        self.assertIsNotNone(inst, "Must have instantiated a NutritionOrder instance")
        self.implNutritionOrder6(inst)
        
        js = inst.as_json()
        self.assertEqual("NutritionOrder", js["resourceType"])
        inst2 = nutritionorder.NutritionOrder(js)
        self.implNutritionOrder6(inst2)
    
    def implNutritionOrder6(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.dateTime.as_json(), "2014-09-17")
        self.assertEqual(inst.enteralFormula.administrationInstructions, "Hold feedings from 7 pm to 7 am. Add MCT oil to increase calories from 1.0 cal/mL to 1.5 cal/mL")
        self.assertEqual(inst.enteralFormula.baseFormulaProductName, " Acme Diabetes Formula")
        self.assertEqual(inst.enteralFormula.baseFormulaType.coding[0].code, "6547210000124112")
        self.assertEqual(inst.enteralFormula.baseFormulaType.coding[0].display, "Diabetic specialty enteral formula")
        self.assertEqual(inst.enteralFormula.baseFormulaType.coding[0].system, "http://snomed/sct")
        self.assertEqual(inst.enteralFormula.caloricDensity.code, "cal/mL")
        self.assertEqual(inst.enteralFormula.caloricDensity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.enteralFormula.caloricDensity.units, "calories per milliliter")
        self.assertEqual(inst.enteralFormula.caloricDensity.value, 1)
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.code, "mL/d")
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.units, "milliliter/day")
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.value, 880)
        self.assertEqual(inst.enteralFormula.rate.denominator.code, "h")
        self.assertEqual(inst.enteralFormula.rate.denominator.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.enteralFormula.rate.denominator.units, "hr")
        self.assertEqual(inst.enteralFormula.rate.denominator.value, 1)
        self.assertEqual(inst.enteralFormula.rate.numerator.code, "mL")
        self.assertEqual(inst.enteralFormula.rate.numerator.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.enteralFormula.rate.numerator.units, "millilters")
        self.assertEqual(inst.enteralFormula.rate.numerator.value, 60)
        self.assertEqual(inst.enteralFormula.rateAdjustment.units, "milliliters every 4 hours")
        self.assertEqual(inst.enteralFormula.rateAdjustment.value, 10)
        self.assertEqual(inst.enteralFormula.routeofAdministration.coding[0].code, "NGT")
        self.assertEqual(inst.enteralFormula.routeofAdministration.coding[0].display, "Instillation, nasogastrostomy tube")
        self.assertEqual(inst.enteralFormula.routeofAdministration.coding[0].system, "http://hl7.org/fhir/v3/RouteOfAdministration")
        self.assertEqual(inst.enteralFormula.scheduled.event[0].date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.enteralFormula.scheduled.event[0].as_json(), "2014-09-17")
        self.assertEqual(inst.id, "enteralcontinuous")
        self.assertEqual(inst.identifier[0].system, "http://www.acme.org/nutritionorders")
        self.assertEqual(inst.identifier[0].value, "123")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.status, "generated")
    
    def testNutritionOrder7(self):
        inst = self.instantiate_from("nutritionorder-example-fiberrestricteddiet.json")
        self.assertIsNotNone(inst, "Must have instantiated a NutritionOrder instance")
        self.implNutritionOrder7(inst)
        
        js = inst.as_json()
        self.assertEqual("NutritionOrder", js["resourceType"])
        inst2 = nutritionorder.NutritionOrder(js)
        self.implNutritionOrder7(inst2)
    
    def implNutritionOrder7(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.dateTime.as_json(), "2014-09-17")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].code, "227493005")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].display, "Cashew Nut")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.excludeFoodModifier[0].coding[0].version, "20140730")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].code, "dairy-free")
        self.assertEqual(inst.foodPreferenceModifier[0].coding[0].system, "http://hl7.org/fhir/diet")
        self.assertEqual(inst.id, "fiberrestricteddiet")
        self.assertEqual(inst.identifier[0].system, "http://goodhealthhospital.org/nutrition-orders")
        self.assertEqual(inst.identifier[0].value, "123")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.code, "g")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.units, "grams")
        self.assertEqual(inst.oralDiet.nutrient[0].amount.value, 50)
        self.assertEqual(inst.oralDiet.nutrient[0].mod.coding[0].code, "256674009")
        self.assertEqual(inst.oralDiet.nutrient[0].mod.coding[0].display, "Fat")
        self.assertEqual(inst.oralDiet.nutrient[0].mod.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.scheduled.repeat.bounds.start.date, FHIRDate("2015-02-10").date)
        self.assertEqual(inst.oralDiet.scheduled.repeat.bounds.start.as_json(), "2015-02-10")
        self.assertEqual(inst.oralDiet.scheduled.repeat.frequency, 3)
        self.assertEqual(inst.oralDiet.scheduled.repeat.period, 1)
        self.assertEqual(inst.oralDiet.scheduled.repeat.periodUnits, "d")
        self.assertEqual(inst.oralDiet.type[0].coding[0].code, "15108003")
        self.assertEqual(inst.oralDiet.type[0].coding[0].display, "Restricted fiber diet")
        self.assertEqual(inst.oralDiet.type[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.type[0].coding[1].code, "1000")
        self.assertEqual(inst.oralDiet.type[0].coding[1].display, "Fiber restricted")
        self.assertEqual(inst.oralDiet.type[0].coding[1].system, "http://goodhealthhospital.org/diet-type-codes")
        self.assertEqual(inst.oralDiet.type[0].text, "Fiber restricted diet")
        self.assertEqual(inst.oralDiet.type[1].coding[0].code, "16208003")
        self.assertEqual(inst.oralDiet.type[1].coding[0].display, "Low fat diet")
        self.assertEqual(inst.oralDiet.type[1].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.type[1].coding[1].code, "1100")
        self.assertEqual(inst.oralDiet.type[1].coding[1].display, "Low Fat")
        self.assertEqual(inst.oralDiet.type[1].coding[1].system, "http://goodhealthhospital.org/diet-type-codes")
        self.assertEqual(inst.oralDiet.type[1].text, "Low fat diet")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.status, "generated")
    
    def testNutritionOrder8(self):
        inst = self.instantiate_from("nutritionorder-example-infantenteral.json")
        self.assertIsNotNone(inst, "Must have instantiated a NutritionOrder instance")
        self.implNutritionOrder8(inst)
        
        js = inst.as_json()
        self.assertEqual("NutritionOrder", js["resourceType"])
        inst2 = nutritionorder.NutritionOrder(js)
        self.implNutritionOrder8(inst2)
    
    def implNutritionOrder8(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.dateTime.as_json(), "2014-09-17")
        self.assertEqual(inst.enteralFormula.additiveProductName, "Acme High Carbohydrate Additive")
        self.assertEqual(inst.enteralFormula.additiveType.coding[0].code, "carbohydrate")
        self.assertEqual(inst.enteralFormula.additiveType.coding[0].display, "Modular carbohydrate enteral formula component")
        self.assertEqual(inst.enteralFormula.additiveType.coding[0].system, "http://hl7.org/fhir/entformula-additive")
        self.assertEqual(inst.enteralFormula.administrationInstructions, "Add high calorie high carbohydrate additive to increase cal/oz from 24 cal/oz to 27 cal/oz.")
        self.assertEqual(inst.enteralFormula.baseFormulaProductName, "Acme Infant Formula + Iron")
        self.assertEqual(inst.enteralFormula.baseFormulaType.coding[0].code, "412414007")
        self.assertEqual(inst.enteralFormula.baseFormulaType.coding[0].display, "infant formula + iron")
        self.assertEqual(inst.enteralFormula.baseFormulaType.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.enteralFormula.caloricDensity.code, "cal/[foz_us]")
        self.assertEqual(inst.enteralFormula.caloricDensity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.enteralFormula.caloricDensity.units, "calories per ounce")
        self.assertEqual(inst.enteralFormula.caloricDensity.value, 20)
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.code, "[foz_us]")
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.units, "ounces")
        self.assertEqual(inst.enteralFormula.maxVolumeToDeliver.value, 32)
        self.assertEqual(inst.enteralFormula.quantity.code, "[foz_us]")
        self.assertEqual(inst.enteralFormula.quantity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.enteralFormula.quantity.units, "ounces")
        self.assertEqual(inst.enteralFormula.quantity.value, 4)
        self.assertEqual(inst.enteralFormula.routeofAdministration.coding[0].code, "PO")
        self.assertEqual(inst.enteralFormula.routeofAdministration.coding[0].display, "Swallow, oral")
        self.assertTrue(inst.enteralFormula.routeofAdministration.coding[0].primary)
        self.assertEqual(inst.enteralFormula.routeofAdministration.coding[0].system, "http://hl7.org/fhir/v3/RouteOfAdministration")
        self.assertEqual(inst.enteralFormula.scheduled.repeat.bounds.start.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.enteralFormula.scheduled.repeat.bounds.start.as_json(), "2014-09-17")
        self.assertEqual(inst.enteralFormula.scheduled.repeat.frequency, 1)
        self.assertEqual(inst.enteralFormula.scheduled.repeat.period, 3)
        self.assertEqual(inst.enteralFormula.scheduled.repeat.periodUnits, "h")
        self.assertEqual(inst.id, "infantenteral")
        self.assertEqual(inst.identifier[0].system, "http://www.acme.org/nutritionorders")
        self.assertEqual(inst.identifier[0].value, "123")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.text.status, "generated")
    
    def testNutritionOrder9(self):
        inst = self.instantiate_from("nutritionorder-example-proteinsupplement.json")
        self.assertIsNotNone(inst, "Must have instantiated a NutritionOrder instance")
        self.implNutritionOrder9(inst)
        
        js = inst.as_json()
        self.assertEqual("NutritionOrder", js["resourceType"])
        inst2 = nutritionorder.NutritionOrder(js)
        self.implNutritionOrder9(inst2)
    
    def implNutritionOrder9(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.dateTime.as_json(), "2014-09-17")
        self.assertEqual(inst.id, "proteinsupplement")
        self.assertEqual(inst.identifier[0].system, "http://goodhealthhospital.org/nutrition-orders")
        self.assertEqual(inst.identifier[0].value, "123")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.supplement[0].instruction, "Beneprotein 1 scoop TID with meal.starting on  2015-02-10")
        self.assertEqual(inst.supplement[0].productName, "Beneprotein")
        self.assertEqual(inst.supplement[0].quantity.code, "{scoop}")
        self.assertEqual(inst.supplement[0].quantity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.supplement[0].quantity.units, "scoop")
        self.assertEqual(inst.supplement[0].quantity.value, 1)
        self.assertEqual(inst.supplement[0].scheduled.repeat.bounds.start.date, FHIRDate("2015-02-10").date)
        self.assertEqual(inst.supplement[0].scheduled.repeat.bounds.start.as_json(), "2015-02-10")
        self.assertEqual(inst.supplement[0].scheduled.repeat.when, "C")
        self.assertEqual(inst.supplement[0].type.coding[0].code, "442991000124104")
        self.assertEqual(inst.supplement[0].type.coding[0].display, "Adult high protein formula")
        self.assertEqual(inst.supplement[0].type.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.supplement[0].type.coding[1].code, "1000")
        self.assertEqual(inst.supplement[0].type.coding[1].display, "High Protein Powder")
        self.assertEqual(inst.supplement[0].type.coding[1].system, "http://goodhealthhospital.org/supplement-type-codes")
        self.assertEqual(inst.supplement[0].type.text, "High Protein Powder")
        self.assertEqual(inst.text.status, "generated")
    
    def testNutritionOrder10(self):
        inst = self.instantiate_from("nutritionorder-example-pureeddiet-simple.json")
        self.assertIsNotNone(inst, "Must have instantiated a NutritionOrder instance")
        self.implNutritionOrder10(inst)
        
        js = inst.as_json()
        self.assertEqual("NutritionOrder", js["resourceType"])
        inst2 = nutritionorder.NutritionOrder(js)
        self.implNutritionOrder10(inst2)
    
    def implNutritionOrder10(self, inst):
        self.assertEqual(inst.dateTime.date, FHIRDate("2014-09-17").date)
        self.assertEqual(inst.dateTime.as_json(), "2014-09-17")
        self.assertEqual(inst.id, "pureeddiet-simple")
        self.assertEqual(inst.identifier[0].system, "http://goodhealthhospital.org/nutrition-orders")
        self.assertEqual(inst.identifier[0].value, "123")
        self.assertEqual(inst.oralDiet.fluidConsistencyType[0].coding[0].code, "439021000124105")
        self.assertEqual(inst.oralDiet.fluidConsistencyType[0].coding[0].display, "Dietary liquid consistency - nectar thick liquid")
        self.assertEqual(inst.oralDiet.fluidConsistencyType[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.fluidConsistencyType[0].text, "Nectar thick liquids")
        self.assertEqual(inst.oralDiet.scheduled.repeat.bounds.start.date, FHIRDate("2015-02-10").date)
        self.assertEqual(inst.oralDiet.scheduled.repeat.bounds.start.as_json(), "2015-02-10")
        self.assertEqual(inst.oralDiet.scheduled.repeat.frequency, 3)
        self.assertEqual(inst.oralDiet.scheduled.repeat.period, 1)
        self.assertEqual(inst.oralDiet.scheduled.repeat.periodUnits, "d")
        self.assertEqual(inst.oralDiet.texture[0].mod.coding[0].code, "228055009")
        self.assertEqual(inst.oralDiet.texture[0].mod.coding[0].display, "Liquidized food")
        self.assertEqual(inst.oralDiet.texture[0].mod.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.texture[0].mod.text, "Pureed")
        self.assertEqual(inst.oralDiet.type[0].coding[0].code, "226211001")
        self.assertEqual(inst.oralDiet.type[0].coding[0].display, "Pureed diet")
        self.assertEqual(inst.oralDiet.type[0].coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.oralDiet.type[0].coding[1].code, "1010")
        self.assertEqual(inst.oralDiet.type[0].coding[1].display, "Pureed diet")
        self.assertEqual(inst.oralDiet.type[0].coding[1].system, "http://goodhealthhospital.org/diet-type-codes")
        self.assertEqual(inst.oralDiet.type[0].text, "Pureed diet")
        self.assertEqual(inst.status, "active")
        self.assertEqual(inst.supplement[0].instruction, "Ensure Pudding at breakfast, lunch, supper")
        self.assertEqual(inst.supplement[0].productName, "Ensure Pudding 4 oz container")
        self.assertEqual(inst.supplement[0].type.coding[0].code, "442971000124100")
        self.assertEqual(inst.supplement[0].type.coding[0].display, "Adult high energy formula")
        self.assertEqual(inst.supplement[0].type.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.supplement[0].type.coding[1].code, "1040")
        self.assertEqual(inst.supplement[0].type.coding[1].display, "Adult high energy pudding")
        self.assertEqual(inst.supplement[0].type.coding[1].system, "http://goodhealthhospital.org/supplement-type-codes")
        self.assertEqual(inst.supplement[0].type.text, "Adult high energy pudding")
        self.assertEqual(inst.text.status, "generated")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 (http://hl7.org/fhir/StructureDefinition/ImagingObjectSelection) on 2015-07-06.
#  2015, SMART Health IT.


from . import codeableconcept
from . import domainresource
from . import fhirdate
from . import fhirelement
from . import fhirreference


class ImagingObjectSelection(domainresource.DomainResource):
    """ Key Object Selection.
    
    A set of DICOM SOP Instances of a patient, selected for some application
    purpose, e.g., quality assurance, teaching, conference, consulting, etc.
    Objects selected can be from different studies, but must be of the same
    patient.
    """
    
    resource_name = "ImagingObjectSelection"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.author = None
        """ Author (human or machine).
        Type `FHIRReference` referencing `Practitioner, Device, Organization, Patient, RelatedPerson` (represented as `dict` in JSON). """
        
        self.authoringTime = None
        """ Authoring time of the selection.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.description = None
        """ Description text.
        Type `str`. """
        
        self.patient = None
        """ Patient of the selected objects.
        Type `FHIRReference` referencing `Patient` (represented as `dict` in JSON). """
        
        self.study = None
        """ Study identity of the selected instances.
        List of `ImagingObjectSelectionStudy` items (represented as `dict` in JSON). """
        
        self.title = None
        """ Reason for selection.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.uid = None
        """ Instance UID.
        Type `str`. """
        
        super(ImagingObjectSelection, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ImagingObjectSelection, self).elementProperties()
        js.extend([
            ("author", "author", fhirreference.FHIRReference, False),
            ("authoringTime", "authoringTime", fhirdate.FHIRDate, False),
            ("description", "description", str, False),
            ("patient", "patient", fhirreference.FHIRReference, False),
            ("study", "study", ImagingObjectSelectionStudy, True),
            ("title", "title", codeableconcept.CodeableConcept, False),
            ("uid", "uid", str, False),
        ])
        return js


class ImagingObjectSelectionStudy(fhirelement.FHIRElement):
    """ Study identity of the selected instances.
    
    Study identity and locating information of the DICOM SOP instances in the
    selection.
    """
    
    resource_name = "ImagingObjectSelectionStudy"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.series = None
        """ Series identity of the selected instances.
        List of `ImagingObjectSelectionStudySeries` items (represented as `dict` in JSON). """
        
        self.uid = None
        """ Study instance uid.
        Type `str`. """
        
        self.url = None
        """ Retrieve URL.
        Type `str`. """
        
        super(ImagingObjectSelectionStudy, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ImagingObjectSelectionStudy, self).elementProperties()
        js.extend([
            ("series", "series", ImagingObjectSelectionStudySeries, True),
            ("uid", "uid", str, False),
            ("url", "url", str, False),
        ])
        return js


class ImagingObjectSelectionStudySeries(fhirelement.FHIRElement):
    """ Series identity of the selected instances.
    
    Series indetity and locating information of the DICOM SOP instances in the
    selection.
    """
    
    resource_name = "ImagingObjectSelectionStudySeries"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.instance = None
        """ The selected instance.
        List of `ImagingObjectSelectionStudySeriesInstance` items (represented as `dict` in JSON). """
        
        self.uid = None
        """ Series instance uid.
        Type `str`. """
        
        self.url = None
        """ Retrieve URL.
        Type `str`. """
        
        super(ImagingObjectSelectionStudySeries, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ImagingObjectSelectionStudySeries, self).elementProperties()
        js.extend([
            ("instance", "instance", ImagingObjectSelectionStudySeriesInstance, True),
            ("uid", "uid", str, False),
            ("url", "url", str, False),
        ])
        return js


class ImagingObjectSelectionStudySeriesInstance(fhirelement.FHIRElement):
    """ The selected instance.
    
    Identity and locating information of the selected DICOM SOP instances.
    """
    
    resource_name = "ImagingObjectSelectionStudySeriesInstance"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.frames = None
        """ The frame set.
        List of `ImagingObjectSelectionStudySeriesInstanceFrames` items (represented as `dict` in JSON). """
        
        self.sopClass = None
        """ SOP class uid of instance.
        Type `str`. """
        
        self.uid = None
        """ Uid of the selected instance.
        Type `str`. """
        
        self.url = None
        """ Retrieve URL.
        Type `str`. """
        
        super(ImagingObjectSelectionStudySeriesInstance, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ImagingObjectSelectionStudySeriesInstance, self).elementProperties()
        js.extend([
            ("frames", "frames", ImagingObjectSelectionStudySeriesInstanceFrames, True),
            ("sopClass", "sopClass", str, False),
            ("uid", "uid", str, False),
            ("url", "url", str, False),
        ])
        return js


class ImagingObjectSelectionStudySeriesInstanceFrames(fhirelement.FHIRElement):
    """ The frame set.
    
    Identity and location information of the frames in the selected instance.
    """
    
    resource_name = "ImagingObjectSelectionStudySeriesInstanceFrames"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.frameNumbers = None
        """ Frame numbers.
        List of `int` items. """
        
        self.url = None
        """ Retrieve URL.
        Type `str`. """
        
        super(ImagingObjectSelectionStudySeriesInstanceFrames, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ImagingObjectSelectionStudySeriesInstanceFrames, self).elementProperties()
        js.extend([
            ("frameNumbers", "frameNumbers", int, True),
            ("url", "url", str, False),
        ])
        return js




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 (http://hl7.org/fhir/StructureDefinition/Parameters) on 2015-07-06.
#  2015, SMART Health IT.


from . import address
from . import attachment
from . import codeableconcept
from . import coding
from . import contactpoint
from . import fhirdate
from . import fhirelement
from . import fhirreference
from . import humanname
from . import identifier
from . import period
from . import quantity
from . import range
from . import ratio
from . import resource
from . import signature
from . import timing


class Parameters(resource.Resource):
    """ Operation Request or Response.
    
    This special resource type is used to represent
    [operation](operations.html] request and response. It has no other use, and
    there is no RESTful end=point associated with it.
    """
    
    resource_name = "Parameters"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.parameter = None
        """ Operation Parameter.
        List of `ParametersParameter` items (represented as `dict` in JSON). """
        
        super(Parameters, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(Parameters, self).elementProperties()
        js.extend([
            ("parameter", "parameter", ParametersParameter, True),
        ])
        return js


class ParametersParameter(fhirelement.FHIRElement):
    """ Operation Parameter.
    
    A parameter passed to or received from the operation.
    """
    
    resource_name = "ParametersParameter"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.name = None
        """ Name from the definition.
        Type `str`. """
        
        self.part = None
        """ Named part of a parameter (e.g. Tuple).
        List of `ParametersParameterPart` items (represented as `dict` in JSON). """
        
        self.resource = None
        """ If parameter is a whole resource.
        Type `Resource` (represented as `dict` in JSON). """
        
        self.valueAddress = None
        """ If parameter is a data type.
        Type `Address` (represented as `dict` in JSON). """
        
        self.valueAttachment = None
        """ If parameter is a data type.
        Type `Attachment` (represented as `dict` in JSON). """
        
        self.valueBase64Binary = None
        """ If parameter is a data type.
        Type `str`. """
        
        self.valueBoolean = None
        """ If parameter is a data type.
        Type `bool`. """
        
        self.valueCode = None
        """ If parameter is a data type.
        Type `str`. """
        
        self.valueCodeableConcept = None
        """ If parameter is a data type.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.valueCoding = None
        """ If parameter is a data type.
        Type `Coding` (represented as `dict` in JSON). """
        
        self.valueContactPoint = None
        """ If parameter is a data type.
        Type `ContactPoint` (represented as `dict` in JSON). """
        
        self.valueDate = None
        """ If parameter is a data type.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.valueDateTime = None
        """ If parameter is a data type.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.valueDecimal = None
        """ If parameter is a data type.
        Type `float`. """
        
        self.valueHumanName = None
        """ If parameter is a data type.
        Type `HumanName` (represented as `dict` in JSON). """
        
        self.valueIdentifier = None
        """ If parameter is a data type.
        Type `Identifier` (represented as `dict` in JSON). """
        
        self.valueInstant = None
        """ If parameter is a data type.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.valueInteger = None
        """ If parameter is a data type.
        Type `int`. """
        
        self.valuePeriod = None
        """ If parameter is a data type.
        Type `Period` (represented as `dict` in JSON). """
        
        self.valueQuantity = None
        """ If parameter is a data type.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.valueRange = None
        """ If parameter is a data type.
        Type `Range` (represented as `dict` in JSON). """
        
        self.valueRatio = None
        """ If parameter is a data type.
        Type `Ratio` (represented as `dict` in JSON). """
        
        self.valueReference = None
        """ If parameter is a data type.
        Type `FHIRReference` (represented as `dict` in JSON). """
        
        self.valueSignature = None
        """ If parameter is a data type.
        Type `Signature` (represented as `dict` in JSON). """
        
        self.valueString = None
        """ If parameter is a data type.
        Type `str`. """
        
        self.valueTime = None
        """ If parameter is a data type.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.valueTiming = None
        """ If parameter is a data type.
        Type `Timing` (represented as `dict` in JSON). """
        
        self.valueUri = None
        """ If parameter is a data type.
        Type `str`. """
        
        super(ParametersParameter, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ParametersParameter, self).elementProperties()
        js.extend([
            ("name", "name", str, False),
            ("part", "part", ParametersParameterPart, True),
            ("resource", "resource", resource.Resource, False),
            ("valueAddress", "valueAddress", address.Address, False),
            ("valueAttachment", "valueAttachment", attachment.Attachment, False),
            ("valueBase64Binary", "valueBase64Binary", str, False),
            ("valueBoolean", "valueBoolean", bool, False),
            ("valueCode", "valueCode", str, False),
            ("valueCodeableConcept", "valueCodeableConcept", codeableconcept.CodeableConcept, False),
            ("valueCoding", "valueCoding", coding.Coding, False),
            ("valueContactPoint", "valueContactPoint", contactpoint.ContactPoint, False),
            ("valueDate", "valueDate", fhirdate.FHIRDate, False),
            ("valueDateTime", "valueDateTime", fhirdate.FHIRDate, False),
            ("valueDecimal", "valueDecimal", float, False),
            ("valueHumanName", "valueHumanName", humanname.HumanName, False),
            ("valueIdentifier", "valueIdentifier", identifier.Identifier, False),
            ("valueInstant", "valueInstant", fhirdate.FHIRDate, False),
            ("valueInteger", "valueInteger", int, False),
            ("valuePeriod", "valuePeriod", period.Period, False),
            ("valueQuantity", "valueQuantity", quantity.Quantity, False),
            ("valueRange", "valueRange", range.Range, False),
            ("valueRatio", "valueRatio", ratio.Ratio, False),
            ("valueReference", "valueReference", fhirreference.FHIRReference, False),
            ("valueSignature", "valueSignature", signature.Signature, False),
            ("valueString", "valueString", str, False),
            ("valueTime", "valueTime", fhirdate.FHIRDate, False),
            ("valueTiming", "valueTiming", timing.Timing, False),
            ("valueUri", "valueUri", str, False),
        ])
        return js


class ParametersParameterPart(fhirelement.FHIRElement):
    """ Named part of a parameter (e.g. Tuple).
    
    A named part of a parameter. In many implementation context, a set of named
    parts is known as a "Tuple".
    """
    
    resource_name = "ParametersParameterPart"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.name = None
        """ Name from the definition.
        Type `str`. """
        
        self.resource = None
        """ If part is a whole resource.
        Type `Resource` (represented as `dict` in JSON). """
        
        self.valueAddress = None
        """ Value of the part.
        Type `Address` (represented as `dict` in JSON). """
        
        self.valueAttachment = None
        """ Value of the part.
        Type `Attachment` (represented as `dict` in JSON). """
        
        self.valueBase64Binary = None
        """ Value of the part.
        Type `str`. """
        
        self.valueBoolean = None
        """ Value of the part.
        Type `bool`. """
        
        self.valueCode = None
        """ Value of the part.
        Type `str`. """
        
        self.valueCodeableConcept = None
        """ Value of the part.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.valueCoding = None
        """ Value of the part.
        Type `Coding` (represented as `dict` in JSON). """
        
        self.valueContactPoint = None
        """ Value of the part.
        Type `ContactPoint` (represented as `dict` in JSON). """
        
        self.valueDate = None
        """ Value of the part.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.valueDateTime = None
        """ Value of the part.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.valueDecimal = None
        """ Value of the part.
        Type `float`. """
        
        self.valueHumanName = None
        """ Value of the part.
        Type `HumanName` (represented as `dict` in JSON). """
        
        self.valueIdentifier = None
        """ Value of the part.
        Type `Identifier` (represented as `dict` in JSON). """
        
        self.valueInstant = None
        """ Value of the part.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.valueInteger = None
        """ Value of the part.
        Type `int`. """
        
        self.valuePeriod = None
        """ Value of the part.
        Type `Period` (represented as `dict` in JSON). """
        
        self.valueQuantity = None
        """ Value of the part.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.valueRange = None
        """ Value of the part.
        Type `Range` (represented as `dict` in JSON). """
        
        self.valueRatio = None
        """ Value of the part.
        Type `Ratio` (represented as `dict` in JSON). """
        
        self.valueReference = None
        """ Value of the part.
        Type `FHIRReference` (represented as `dict` in JSON). """
        
        self.valueSignature = None
        """ Value of the part.
        Type `Signature` (represented as `dict` in JSON). """
        
        self.valueString = None
        """ Value of the part.
        Type `str`. """
        
        self.valueTime = None
        """ Value of the part.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.valueTiming = None
        """ Value of the part.
        Type `Timing` (represented as `dict` in JSON). """
        
        self.valueUri = None
        """ Value of the part.
        Type `str`. """
        
        super(ParametersParameterPart, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ParametersParameterPart, self).elementProperties()
        js.extend([
            ("name", "name", str, False),
            ("resource", "resource", resource.Resource, False),
            ("valueAddress", "valueAddress", address.Address, False),
            ("valueAttachment", "valueAttachment", attachment.Attachment, False),
            ("valueBase64Binary", "valueBase64Binary", str, False),
            ("valueBoolean", "valueBoolean", bool, False),
            ("valueCode", "valueCode", str, False),
            ("valueCodeableConcept", "valueCodeableConcept", codeableconcept.CodeableConcept, False),
            ("valueCoding", "valueCoding", coding.Coding, False),
            ("valueContactPoint", "valueContactPoint", contactpoint.ContactPoint, False),
            ("valueDate", "valueDate", fhirdate.FHIRDate, False),
            ("valueDateTime", "valueDateTime", fhirdate.FHIRDate, False),
            ("valueDecimal", "valueDecimal", float, False),
            ("valueHumanName", "valueHumanName", humanname.HumanName, False),
            ("valueIdentifier", "valueIdentifier", identifier.Identifier, False),
            ("valueInstant", "valueInstant", fhirdate.FHIRDate, False),
            ("valueInteger", "valueInteger", int, False),
            ("valuePeriod", "valuePeriod", period.Period, False),
            ("valueQuantity", "valueQuantity", quantity.Quantity, False),
            ("valueRange", "valueRange", range.Range, False),
            ("valueRatio", "valueRatio", ratio.Ratio, False),
            ("valueReference", "valueReference", fhirreference.FHIRReference, False),
            ("valueSignature", "valueSignature", signature.Signature, False),
            ("valueString", "valueString", str, False),
            ("valueTime", "valueTime", fhirdate.FHIRDate, False),
            ("valueTiming", "valueTiming", timing.Timing, False),
            ("valueUri", "valueUri", str, False),
        ])
        return js




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 (http://hl7.org/fhir/StructureDefinition/MedicationStatement) on 2015-07-06.
#  2015, SMART Health IT.


from . import codeableconcept
from . import domainresource
from . import fhirdate
from . import fhirelement
from . import fhirreference
from . import identifier
from . import period
from . import quantity
from . import ratio
from . import timing


class MedicationStatement(domainresource.DomainResource):
    """ Administration of medication to a patient.
    
    A record of medication being taken by a patient, or that the medication has
    been given to a patient where the record is the result of a report from the
    patient or another clinician.
    """
    
    resource_name = "MedicationStatement"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.dateAsserted = None
        """ When the statement was asserted?.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.dosage = None
        """ Details of how medication was taken.
        List of `MedicationStatementDosage` items (represented as `dict` in JSON). """
        
        self.effectiveDateTime = None
        """ Over what period was medication consumed?.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.effectivePeriod = None
        """ Over what period was medication consumed?.
        Type `Period` (represented as `dict` in JSON). """
        
        self.identifier = None
        """ External Identifier.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.informationSource = None
        """ The person who provided the information about the taking of this
        medication..
        Type `FHIRReference` referencing `Patient, Practitioner, RelatedPerson` (represented as `dict` in JSON). """
        
        self.medication = None
        """ What medication was taken?.
        Type `FHIRReference` referencing `Medication` (represented as `dict` in JSON). """
        
        self.note = None
        """ Further information about the statement.
        Type `str`. """
        
        self.patient = None
        """ Who was/is taking medication.
        Type `FHIRReference` referencing `Patient` (represented as `dict` in JSON). """
        
        self.reasonForUseCodeableConcept = None
        """ A reason for why the medication is being/was taken..
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.reasonForUseReference = None
        """ A reason for why the medication is being/was taken..
        Type `FHIRReference` referencing `Condition` (represented as `dict` in JSON). """
        
        self.reasonNotGiven = None
        """ True if asserting medication was not given.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.status = None
        """ in-progress | completed | entered-in-error.
        Type `str`. """
        
        self.wasNotGiven = None
        """ True if medication is/was not being taken.
        Type `bool`. """
        
        super(MedicationStatement, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(MedicationStatement, self).elementProperties()
        js.extend([
            ("dateAsserted", "dateAsserted", fhirdate.FHIRDate, False),
            ("dosage", "dosage", MedicationStatementDosage, True),
            ("effectiveDateTime", "effectiveDateTime", fhirdate.FHIRDate, False),
            ("effectivePeriod", "effectivePeriod", period.Period, False),
            ("identifier", "identifier", identifier.Identifier, True),
            ("informationSource", "informationSource", fhirreference.FHIRReference, False),
            ("medication", "medication", fhirreference.FHIRReference, False),
            ("note", "note", str, False),
            ("patient", "patient", fhirreference.FHIRReference, False),
            ("reasonForUseCodeableConcept", "reasonForUseCodeableConcept", codeableconcept.CodeableConcept, False),
            ("reasonForUseReference", "reasonForUseReference", fhirreference.FHIRReference, False),
            ("reasonNotGiven", "reasonNotGiven", codeableconcept.CodeableConcept, True),
            ("status", "status", str, False),
            ("wasNotGiven", "wasNotGiven", bool, False),
        ])
        return js


class MedicationStatementDosage(fhirelement.FHIRElement):
    """ Details of how medication was taken.
    
    Indicates how the medication is/was used by the patient.
    """
    
    resource_name = "MedicationStatementDosage"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.asNeededBoolean = None
        """ Take "as needed" f(or x).
        Type `bool`. """
        
        self.asNeededCodeableConcept = None
        """ Take "as needed" f(or x).
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.maxDosePerPeriod = None
        """ Maximum dose that was consumed per unit of time.
        Type `Ratio` (represented as `dict` in JSON). """
        
        self.method = None
        """ Technique used to administer medication.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.quantity = None
        """ Amount administered in one dose.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.rate = None
        """ Dose quantity per unit of time.
        Type `Ratio` (represented as `dict` in JSON). """
        
        self.route = None
        """ How did the medication enter the body?.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.schedule = None
        """ When/how often was medication taken?.
        Type `Timing` (represented as `dict` in JSON). """
        
        self.site = None
        """ Where on body was medication administered?.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.text = None
        """ Dosage Instructions.
        Type `str`. """
        
        super(MedicationStatementDosage, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(MedicationStatementDosage, self).elementProperties()
        js.extend([
            ("asNeededBoolean", "asNeededBoolean", bool, False),
            ("asNeededCodeableConcept", "asNeededCodeableConcept", codeableconcept.CodeableConcept, False),
            ("maxDosePerPeriod", "maxDosePerPeriod", ratio.Ratio, False),
            ("method", "method", codeableconcept.CodeableConcept, False),
            ("quantity", "quantity", quantity.Quantity, False),
            ("rate", "rate", ratio.Ratio, False),
            ("route", "route", codeableconcept.CodeableConcept, False),
            ("schedule", "schedule", timing.Timing, False),
            ("site", "site", codeableconcept.CodeableConcept, False),
            ("text", "text", str, False),
        ])
        return js




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import valueset
from .fhirdate import FHIRDate


class ValueSetTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("ValueSet", js["resourceType"])
        return valueset.ValueSet(js)
    
    def testValueSet1(self):
        inst = self.instantiate_from("valueset-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a ValueSet instance")
        self.implValueSet1(inst)
        
        js = inst.as_json()
        self.assertEqual("ValueSet", js["resourceType"])
        inst2 = valueset.ValueSet(js)
        self.implValueSet1(inst2)
    
    def implValueSet1(self, inst):
        self.assertEqual(inst.compose.include[0].concept[0].code, "14647-2")
        self.assertEqual(inst.compose.include[0].concept[1].code, "2093-3")
        self.assertEqual(inst.compose.include[0].concept[2].code, "35200-5")
        self.assertEqual(inst.compose.include[0].concept[3].code, "9342-7")
        self.assertEqual(inst.compose.include[0].system, "http://loinc.org")
        self.assertEqual(inst.compose.include[0].version, "2.36")
        self.assertEqual(inst.contact[0].telecom[0].system, "url")
        self.assertEqual(inst.contact[0].telecom[0].value, "http://hl7.org/fhir")
        self.assertEqual(inst.copyright, "This content from LOINC® is copyright © 1995 Regenstrief Institute, Inc. and the LOINC Committee, and available at no cost under the license at http://loinc.org/terms-of-use")
        self.assertEqual(inst.date.date, FHIRDate("2012-06-13").date)
        self.assertEqual(inst.date.as_json(), "2012-06-13")
        self.assertEqual(inst.description, "This is an example value set that includes        all the LOINC codes for serum cholesterol from v2.36")
        self.assertTrue(inst.experimental)
        self.assertEqual(inst.id, "101")
        self.assertEqual(inst.name, "LOINC Codes for Cholesterol")
        self.assertEqual(inst.publisher, "FHIR project team (example)")
        self.assertEqual(inst.status, "draft")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.url, "urn:uuid:256a5231-a2bb-49bd-9fea-f349d428b70d")
        self.assertEqual(inst.version, "20120613")
    
    def testValueSet2(self):
        inst = self.instantiate_from("valueset-list-example-codes.json")
        self.assertIsNotNone(inst, "Must have instantiated a ValueSet instance")
        self.implValueSet2(inst)
        
        js = inst.as_json()
        self.assertEqual("ValueSet", js["resourceType"])
        inst2 = valueset.ValueSet(js)
        self.implValueSet2(inst2)
    
    def implValueSet2(self, inst):
        self.assertEqual(inst.contact[0].telecom[0].system, "url")
        self.assertEqual(inst.contact[0].telecom[0].value, "http://hl7.org/fhir")
        self.assertTrue(inst.define.caseSensitive)
        self.assertEqual(inst.define.concept[0].code, "alerts")
        self.assertEqual(inst.define.concept[0].definition, "A list of alerts for the patient")
        self.assertEqual(inst.define.concept[0].display, "Alerts")
        self.assertEqual(inst.define.concept[1].code, "adverserxns")
        self.assertEqual(inst.define.concept[1].definition, "A list of part adverse reactions")
        self.assertEqual(inst.define.concept[1].display, "Adverse Reactions")
        self.assertEqual(inst.define.concept[2].code, "allergies")
        self.assertEqual(inst.define.concept[2].definition, "A list of Allergies for the patient")
        self.assertEqual(inst.define.concept[2].display, "Allergies")
        self.assertEqual(inst.define.concept[3].code, "medications")
        self.assertEqual(inst.define.concept[3].definition, "A list of medication statements for the patient")
        self.assertEqual(inst.define.concept[3].display, "Medication List")
        self.assertEqual(inst.define.concept[4].code, "problems")
        self.assertEqual(inst.define.concept[4].definition, "A list of problems that the patient is known of have (or have had in the past)")
        self.assertEqual(inst.define.concept[4].display, "Problem List")
        self.assertEqual(inst.define.concept[5].code, "worklist")
        self.assertEqual(inst.define.concept[5].definition, "A list of items that constitute a set of work to be performed (typically this code would be specialised for more specific uses, such as a ward round list)")
        self.assertEqual(inst.define.concept[5].display, "Worklist")
        self.assertEqual(inst.define.concept[6].code, "waiting")
        self.assertEqual(inst.define.concept[6].definition, "A list of items waiting for an event (perhaps a surgical patient waiting list)")
        self.assertEqual(inst.define.concept[6].display, "Waiting List")
        self.assertEqual(inst.define.concept[7].code, "protocols")
        self.assertEqual(inst.define.concept[7].definition, "A set of protocols to be followed")
        self.assertEqual(inst.define.concept[7].display, "Protocols")
        self.assertEqual(inst.define.concept[8].code, "plans")
        self.assertEqual(inst.define.concept[8].definition, "A set of care plans that apply in a particular context of care")
        self.assertEqual(inst.define.concept[8].display, "Care Plans")
        self.assertEqual(inst.define.extension[0].url, "http://hl7.org/fhir/StructureDefinition/valueset-oid")
        self.assertEqual(inst.define.extension[0].valueUri, "urn:oid:null")
        self.assertEqual(inst.define.system, "http://hl7.org/fhir/list-example-use-codes")
        self.assertEqual(inst.description, "Example use codes for the List resource - typical kinds of use. TODO: Does LOINC define useful codes?")
        self.assertTrue(inst.experimental)
        self.assertEqual(inst.extension[0].url, "http://hl7.org/fhir/StructureDefinition/valueset-oid")
        self.assertEqual(inst.extension[0].valueUri, "urn:oid:2.16.840.1.113883.4.642.2.320")
        self.assertEqual(inst.id, "valueset-list-example-codes")
        self.assertEqual(inst.meta.lastUpdated.date, FHIRDate("2015-04-03T14:24:32.000+11:00").date)
        self.assertEqual(inst.meta.lastUpdated.as_json(), "2015-04-03T14:24:32.000+11:00")
        self.assertEqual(inst.meta.profile[0], "http://hl7.org/fhir/StructureDefinition/valueset-shareable-definition")
        self.assertEqual(inst.name, "Example Use Codes for List")
        self.assertEqual(inst.publisher, "FHIR Project")
        self.assertEqual(inst.status, "draft")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.url, "http://hl7.org/fhir/vs/list-example-codes")
        self.assertEqual(inst.version, "0.5.0")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 (http://hl7.org/fhir/StructureDefinition/Group) on 2015-07-06.
#  2015, SMART Health IT.


from . import codeableconcept
from . import domainresource
from . import fhirelement
from . import fhirreference
from . import identifier
from . import quantity
from . import range


class Group(domainresource.DomainResource):
    """ Group of multiple entities.
    
    Represents a defined collection of entities that may be discussed or acted
    upon collectively but which are not expected to act collectively and are
    not formally or legally recognized.  I.e. A collection of entities that
    isn't an Organization.
    """
    
    resource_name = "Group"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.actual = None
        """ Descriptive or actual.
        Type `bool`. """
        
        self.characteristic = None
        """ Trait of group members.
        List of `GroupCharacteristic` items (represented as `dict` in JSON). """
        
        self.code = None
        """ Kind of Group members.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.identifier = None
        """ Unique id.
        Type `Identifier` (represented as `dict` in JSON). """
        
        self.member = None
        """ Who or what is in group.
        List of `FHIRReference` items referencing `Patient, Practitioner, Device, Medication, Substance` (represented as `dict` in JSON). """
        
        self.name = None
        """ Label for Group.
        Type `str`. """
        
        self.quantity = None
        """ Number of members.
        Type `int`. """
        
        self.type = None
        """ person | animal | practitioner | device | medication | substance.
        Type `str`. """
        
        super(Group, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(Group, self).elementProperties()
        js.extend([
            ("actual", "actual", bool, False),
            ("characteristic", "characteristic", GroupCharacteristic, True),
            ("code", "code", codeableconcept.CodeableConcept, False),
            ("identifier", "identifier", identifier.Identifier, False),
            ("member", "member", fhirreference.FHIRReference, True),
            ("name", "name", str, False),
            ("quantity", "quantity", int, False),
            ("type", "type", str, False),
        ])
        return js


class GroupCharacteristic(fhirelement.FHIRElement):
    """ Trait of group members.
    
    Identifies the traits shared by members of the group.
    """
    
    resource_name = "GroupCharacteristic"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.code = None
        """ Kind of characteristic.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.exclude = None
        """ Group includes or excludes.
        Type `bool`. """
        
        self.valueBoolean = None
        """ Value held by characteristic.
        Type `bool`. """
        
        self.valueCodeableConcept = None
        """ Value held by characteristic.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.valueQuantity = None
        """ Value held by characteristic.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.valueRange = None
        """ Value held by characteristic.
        Type `Range` (represented as `dict` in JSON). """
        
        super(GroupCharacteristic, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(GroupCharacteristic, self).elementProperties()
        js.extend([
            ("code", "code", codeableconcept.CodeableConcept, False),
            ("exclude", "exclude", bool, False),
            ("valueBoolean", "valueBoolean", bool, False),
            ("valueCodeableConcept", "valueCodeableConcept", codeableconcept.CodeableConcept, False),
            ("valueQuantity", "valueQuantity", quantity.Quantity, False),
            ("valueRange", "valueRange", range.Range, False),
        ])
        return js




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import substance
from .fhirdate import FHIRDate


class SubstanceTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Substance", js["resourceType"])
        return substance.Substance(js)
    
    def testSubstance1(self):
        inst = self.instantiate_from("substance-example-f201-dust.json")
        self.assertIsNotNone(inst, "Must have instantiated a Substance instance")
        self.implSubstance1(inst)
        
        js = inst.as_json()
        self.assertEqual("Substance", js["resourceType"])
        inst2 = substance.Substance(js)
        self.implSubstance1(inst2)
    
    def implSubstance1(self, inst):
        self.assertEqual(inst.id, "f201")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.type.coding[0].code, "406466009")
        self.assertEqual(inst.type.coding[0].display, "House dust allergen")
        self.assertEqual(inst.type.coding[0].system, "http://snomed.info/sct")
    
    def testSubstance2(self):
        inst = self.instantiate_from("substance-example-f202-staphylococcus.json")
        self.assertIsNotNone(inst, "Must have instantiated a Substance instance")
        self.implSubstance2(inst)
        
        js = inst.as_json()
        self.assertEqual("Substance", js["resourceType"])
        inst2 = substance.Substance(js)
        self.implSubstance2(inst2)
    
    def implSubstance2(self, inst):
        self.assertEqual(inst.id, "f202")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.type.coding[0].code, "3092008")
        self.assertEqual(inst.type.coding[0].display, "Staphylococcus Aureus")
        self.assertEqual(inst.type.coding[0].system, "http://snomed.info/sct")
    
    def testSubstance3(self):
        inst = self.instantiate_from("substance-example-f203-potassium.json")
        self.assertIsNotNone(inst, "Must have instantiated a Substance instance")
        self.implSubstance3(inst)
        
        js = inst.as_json()
        self.assertEqual("Substance", js["resourceType"])
        inst2 = substance.Substance(js)
        self.implSubstance3(inst2)
    
    def implSubstance3(self, inst):
        self.assertEqual(inst.id, "f203")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.type.coding[0].code, "88480006")
        self.assertEqual(inst.type.coding[0].display, "Potassium")
        self.assertEqual(inst.type.coding[0].system, "http://snomed.info/sct")
    
    def testSubstance4(self):
        inst = self.instantiate_from("substance-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Substance instance")
        self.implSubstance4(inst)
        
        js = inst.as_json()
        self.assertEqual("Substance", js["resourceType"])
        inst2 = substance.Substance(js)
        self.implSubstance4(inst2)
    
    def implSubstance4(self, inst):
        self.assertEqual(inst.id, "example")
        self.assertEqual(inst.text.div, "<div>Apitoxin (known as Honey Bee Venom)</div>")
        self.assertEqual(inst.text.status, "generated")
        self.assertEqual(inst.type.text, "apitoxin")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import medicationstatement
from .fhirdate import FHIRDate


class MedicationStatementTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("MedicationStatement", js["resourceType"])
        return medicationstatement.MedicationStatement(js)
    
    def testMedicationStatement1(self):
        inst = self.instantiate_from("medicationstatement-example-tylenol.json")
        self.assertIsNotNone(inst, "Must have instantiated a MedicationStatement instance")
        self.implMedicationStatement1(inst)
        
        js = inst.as_json()
        self.assertEqual("MedicationStatement", js["resourceType"])
        inst2 = medicationstatement.MedicationStatement(js)
        self.implMedicationStatement1(inst2)
    
    def implMedicationStatement1(self, inst):
        self.assertTrue(inst.dosage[0].asNeededBoolean)
        self.assertEqual(inst.dosage[0].quantity.value, 1)
        self.assertEqual(inst.dosage[0].route.coding[0].code, "394899003")
        self.assertEqual(inst.dosage[0].route.coding[0].display, "oral administration of treatment")
        self.assertEqual(inst.dosage[0].route.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.dosage[0].schedule.repeat.frequency, 1)
        self.assertEqual(inst.dosage[0].schedule.repeat.period, 1)
        self.assertEqual(inst.dosage[0].schedule.repeat.periodUnits, "d")
        self.assertEqual(inst.effectiveDateTime.date, FHIRDate("2010").date)
        self.assertEqual(inst.effectiveDateTime.as_json(), "2010")
        self.assertEqual(inst.id, "tylenol")
        self.assertEqual(inst.status, "completed")
        self.assertEqual(inst.text.status, "generated")
    
    def testMedicationStatement2(self):
        inst = self.instantiate_from("medicationstatement-qicore-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a MedicationStatement instance")
        self.implMedicationStatement2(inst)
        
        js = inst.as_json()
        self.assertEqual("MedicationStatement", js["resourceType"])
        inst2 = medicationstatement.MedicationStatement(js)
        self.implMedicationStatement2(inst2)
    
    def implMedicationStatement2(self, inst):
        self.assertEqual(inst.dosage[0].quantity.code, "ml")
        self.assertEqual(inst.dosage[0].quantity.system, "http://unitsofmeasure.org")
        self.assertEqual(inst.dosage[0].quantity.units, "ml")
        self.assertEqual(inst.dosage[0].quantity.value, 10)
        self.assertEqual(inst.dosage[0].route.coding[0].code, "394899003")
        self.assertEqual(inst.dosage[0].route.coding[0].display, "oral administration of treatment")
        self.assertEqual(inst.dosage[0].route.coding[0].system, "http://snomed.info/sct")
        self.assertEqual(inst.effectiveDateTime.date, FHIRDate("2012-06-01T14:30:00+14:00").date)
        self.assertEqual(inst.effectiveDateTime.as_json(), "2012-06-01T14:30:00+14:00")
        self.assertEqual(inst.id, "qicore")
        self.assertEqual(inst.status, "completed")
        self.assertEqual(inst.text.status, "generated")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import auditevent
from .fhirdate import FHIRDate


class AuditEventTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("AuditEvent", js["resourceType"])
        return auditevent.AuditEvent(js)
    
    def testAuditEvent1(self):
        inst = self.instantiate_from("audit-event-example-login.json")
        self.assertIsNotNone(inst, "Must have instantiated a AuditEvent instance")
        self.implAuditEvent1(inst)
        
        js = inst.as_json()
        self.assertEqual("AuditEvent", js["resourceType"])
        inst2 = auditevent.AuditEvent(js)
        self.implAuditEvent1(inst2)
    
    def implAuditEvent1(self, inst):
        self.assertEqual(inst.event.action, "E")
        self.assertEqual(inst.event.dateTime.date, FHIRDate("2013-06-20T23:41:23Z").date)
        self.assertEqual(inst.event.dateTime.as_json(), "2013-06-20T23:41:23Z")
        self.assertEqual(inst.event.outcome, "0")
        self.assertEqual(inst.event.subtype[0].coding[0].code, "110122")
        self.assertEqual(inst.event.subtype[0].coding[0].display, "Login")
        self.assertEqual(inst.event.subtype[0].coding[0].system, "http://nema.org/dicom/dicm")
        self.assertEqual(inst.event.type.coding[0].code, "110114")
        self.assertEqual(inst.event.type.coding[0].display, "User Authentication")
        self.assertEqual(inst.event.type.coding[0].system, "http://nema.org/dicom/dicm")
        self.assertEqual(inst.id, "example-login")
        self.assertEqual(inst.participant[0].altId, "601847123")
        self.assertEqual(inst.participant[0].name, "Grahame Grieve")
        self.assertEqual(inst.participant[0].network.identifier, "127.0.0.1")
        self.assertEqual(inst.participant[0].network.type, "2")
        self.assertTrue(inst.participant[0].requestor)
        self.assertEqual(inst.participant[0].userId, "95")
        self.assertEqual(inst.source.identifier, "hl7connect.healthintersections.com.au")
        self.assertEqual(inst.source.site, "Cloud")
        self.assertEqual(inst.source.type[0].code, "3")
        self.assertEqual(inst.source.type[0].display, "Web Server")
        self.assertEqual(inst.source.type[0].system, "http://hl7.org/fhir/security-source-type")
        self.assertEqual(inst.text.status, "generated")
    
    def testAuditEvent2(self):
        inst = self.instantiate_from("audit-event-example-logout.json")
        self.assertIsNotNone(inst, "Must have instantiated a AuditEvent instance")
        self.implAuditEvent2(inst)
        
        js = inst.as_json()
        self.assertEqual("AuditEvent", js["resourceType"])
        inst2 = auditevent.AuditEvent(js)
        self.implAuditEvent2(inst2)
    
    def implAuditEvent2(self, inst):
        self.assertEqual(inst.event.action, "E")
        self.assertEqual(inst.event.dateTime.date, FHIRDate("2013-06-20T23:46:41Z").date)
        self.assertEqual(inst.event.dateTime.as_json(), "2013-06-20T23:46:41Z")
        self.assertEqual(inst.event.outcome, "0")
        self.assertEqual(inst.event.subtype[0].coding[0].code, "110123")
        self.assertEqual(inst.event.subtype[0].coding[0].display, "Logout")
        self.assertEqual(inst.event.subtype[0].coding[0].system, "http://nema.org/dicom/dicm")
        self.assertEqual(inst.event.type.coding[0].code, "110114")
        self.assertEqual(inst.event.type.coding[0].display, "User Authentication")
        self.assertEqual(inst.event.type.coding[0].system, "http://nema.org/dicom/dicm")
        self.assertEqual(inst.id, "example-logout")
        self.assertEqual(inst.participant[0].altId, "601847123")
        self.assertEqual(inst.participant[0].name, "Grahame Grieve")
        self.assertEqual(inst.participant[0].network.identifier, "127.0.0.1")
        self.assertEqual(inst.participant[0].network.type, "2")
        self.assertTrue(inst.participant[0].requestor)
        self.assertEqual(inst.participant[0].userId, "95")
        self.assertEqual(inst.source.identifier, "hl7connect.healthintersections.com.au")
        self.assertEqual(inst.source.site, "Cloud")
        self.assertEqual(inst.source.type[0].code, "3")
        self.assertEqual(inst.source.type[0].display, "Web Server")
        self.assertEqual(inst.source.type[0].system, "http://hl7.org/fhir/security-source-type")
        self.assertEqual(inst.text.status, "generated")
    
    def testAuditEvent3(self):
        inst = self.instantiate_from("audit-event-example-vread.json")
        self.assertIsNotNone(inst, "Must have instantiated a AuditEvent instance")
        self.implAuditEvent3(inst)
        
        js = inst.as_json()
        self.assertEqual("AuditEvent", js["resourceType"])
        inst2 = auditevent.AuditEvent(js)
        self.implAuditEvent3(inst2)
    
    def implAuditEvent3(self, inst):
        self.assertEqual(inst.event.action, "R")
        self.assertEqual(inst.event.dateTime.date, FHIRDate("2013-06-20T23:42:24Z").date)
        self.assertEqual(inst.event.dateTime.as_json(), "2013-06-20T23:42:24Z")
        self.assertEqual(inst.event.outcome, "0")
        self.assertEqual(inst.event.subtype[0].coding[0].code, "vread")
        self.assertEqual(inst.event.subtype[0].coding[0].display, "vread")
        self.assertEqual(inst.event.subtype[0].coding[0].system, "http://hl7.org/fhir/restful-interaction")
        self.assertEqual(inst.event.type.coding[0].code, "rest")
        self.assertEqual(inst.event.type.coding[0].display, "Restful Operation")
        self.assertEqual(inst.event.type.coding[0].system, "http://hl7.org/fhir/audit-event-type")
        self.assertEqual(inst.id, "example-rest")
        self.assertEqual(inst.object[0].lifecycle, "6")
        self.assertEqual(inst.object[0].type, "2")
        self.assertEqual(inst.participant[0].altId, "601847123")
        self.assertEqual(inst.participant[0].name, "Grahame Grieve")
        self.assertTrue(inst.participant[0].requestor)
        self.assertEqual(inst.participant[0].userId, "95")
        self.assertEqual(inst.source.identifier, "hl7connect.healthintersections.com.au")
        self.assertEqual(inst.source.site, "Cloud")
        self.assertEqual(inst.source.type[0].code, "3")
        self.assertEqual(inst.source.type[0].display, "Web Server")
        self.assertEqual(inst.source.type[0].system, "http://hl7.org/fhir/security-source-type")
        self.assertEqual(inst.text.status, "generated")
    
    def testAuditEvent4(self):
        inst = self.instantiate_from("auditevent-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a AuditEvent instance")
        self.implAuditEvent4(inst)
        
        js = inst.as_json()
        self.assertEqual("AuditEvent", js["resourceType"])
        inst2 = auditevent.AuditEvent(js)
        self.implAuditEvent4(inst2)
    
    def implAuditEvent4(self, inst):
        self.assertEqual(inst.event.action, "E")
        self.assertEqual(inst.event.dateTime.date, FHIRDate("2012-10-25T22:04:27+11:00").date)
        self.assertEqual(inst.event.dateTime.as_json(), "2012-10-25T22:04:27+11:00")
        self.assertEqual(inst.event.outcome, "0")
        self.assertEqual(inst.event.subtype[0].coding[0].code, "110120")
        self.assertEqual(inst.event.subtype[0].coding[0].display, "Application Start")
        self.assertEqual(inst.event.subtype[0].coding[0].system, "http://nema.org/dicom/dicm")
        self.assertEqual(inst.event.type.coding[0].code, "110100")
        self.assertEqual(inst.event.type.coding[0].display, "Application Activity")
        self.assertEqual(inst.event.type.coding[0].system, "http://nema.org/dicom/dicm")
        self.assertEqual(inst.id, "example")
        self.assertEqual(inst.object[0].identifier.type.coding[0].code, "SNO")
        self.assertEqual(inst.object[0].identifier.type.coding[0].system, "http://hl7.org/fhir/v2/0203")
        self.assertEqual(inst.object[0].identifier.type.text, "Dell Serial Number")
        self.assertEqual(inst.object[0].identifier.value, "ABCDEF")
        self.assertEqual(inst.object[0].lifecycle, "6")
        self.assertEqual(inst.object[0].name, "Grahame's Laptop")
        self.assertEqual(inst.object[0].role, "4")
        self.assertEqual(inst.object[0].type, "4")
        self.assertEqual(inst.participant[0].network.identifier, "127.0.0.1")
        self.assertEqual(inst.participant[0].network.type, "2")
        self.assertFalse(inst.participant[0].requestor)
        self.assertEqual(inst.participant[0].role[0].text, "Service User (Logon)")
        self.assertEqual(inst.participant[0].userId, "Grahame")
        self.assertEqual(inst.source.identifier, "Grahame's Laptop")
        self.assertEqual(inst.source.site, "Development")
        self.assertEqual(inst.source.type[0].code, "1")
        self.assertEqual(inst.source.type[0].system, "http://hl7.org/fhir/audit-event-sub-type")
        self.assertEqual(inst.text.div, "<div>Application Start for under service login &quot;Grahame&quot; (id: Grahame's Test HL7Connect)</div>")
        self.assertEqual(inst.text.status, "generated")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import paymentnotice
from .fhirdate import FHIRDate


class PaymentNoticeTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("PaymentNotice", js["resourceType"])
        return paymentnotice.PaymentNotice(js)
    
    def testPaymentNotice1(self):
        inst = self.instantiate_from("paymentnotice-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a PaymentNotice instance")
        self.implPaymentNotice1(inst)
        
        js = inst.as_json()
        self.assertEqual("PaymentNotice", js["resourceType"])
        inst2 = paymentnotice.PaymentNotice(js)
        self.implPaymentNotice1(inst2)
    
    def implPaymentNotice1(self, inst):
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(inst.id, "77654")
        self.assertEqual(inst.identifier[0].system, "http://benefitsinc.com/paymentnotice")
        self.assertEqual(inst.identifier[0].value, "776543")
        self.assertEqual(inst.paymentStatus.code, "paid")
        self.assertEqual(inst.paymentStatus.system, "http://hl7.org/fhir/paymentstatus")
        self.assertEqual(inst.text.div, "<div>A human-readable rendering of the PaymentNotice</div>")
        self.assertEqual(inst.text.status, "generated")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 on 2015-07-06.
#  2015, SMART Health IT.


import os
import io
import unittest
import json
from . import provenance
from .fhirdate import FHIRDate


class ProvenanceTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Provenance", js["resourceType"])
        return provenance.Provenance(js)
    
    def testProvenance1(self):
        inst = self.instantiate_from("provenance-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Provenance instance")
        self.implProvenance1(inst)
        
        js = inst.as_json()
        self.assertEqual("Provenance", js["resourceType"])
        inst2 = provenance.Provenance(js)
        self.implProvenance1(inst2)
    
    def implProvenance1(self, inst):
        self.assertEqual(inst.agent[0].display, "Grahame Grieve")
        self.assertEqual(inst.agent[0].referenceUri, "mailto:grahame@healthintersections.com.au")
        self.assertEqual(inst.agent[0].role.code, "author")
        self.assertEqual(inst.agent[0].role.system, "http://hl7.org/fhir/provenance-participant-role")
        self.assertEqual(inst.agent[0].type.code, "person")
        self.assertEqual(inst.agent[0].type.system, "http://hl7.org/fhir/provenance-participant-type")
        self.assertEqual(inst.id, "example")
        self.assertEqual(inst.period.start.date, FHIRDate("2011-06-23").date)
        self.assertEqual(inst.period.start.as_json(), "2011-06-23")
        self.assertEqual(inst.reason.text, "Editing the FHIR Specification")
        self.assertEqual(inst.recorded.date, FHIRDate("2012-11-08T23:16:03+11:00").date)
        self.assertEqual(inst.recorded.as_json(), "2012-11-08T23:16:03+11:00")
        self.assertEqual(inst.text.div, "<div>Authored on 8-Nov 2011 by Grahame Grieve. Content extracted from ISO-21090</div>")
        self.assertEqual(inst.text.status, "generated")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 (http://hl7.org/fhir/StructureDefinition/ValueSet) on 2015-07-06.
#  2015, SMART Health IT.


from . import codeableconcept
from . import coding
from . import contactpoint
from . import domainresource
from . import fhirdate
from . import fhirelement
from . import identifier


class ValueSet(domainresource.DomainResource):
    """ A set of codes drawn from one or more code systems.
    
    A value set specifies a set of codes drawn from one or more code systems.
    """
    
    resource_name = "ValueSet"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.compose = None
        """ When value set includes codes from elsewhere.
        Type `ValueSetCompose` (represented as `dict` in JSON). """
        
        self.contact = None
        """ Contact details of the publisher.
        List of `ValueSetContact` items (represented as `dict` in JSON). """
        
        self.copyright = None
        """ Use and/or Publishing restrictions.
        Type `str`. """
        
        self.date = None
        """ Date for given status.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.define = None
        """ When value set defines its own codes.
        Type `ValueSetDefine` (represented as `dict` in JSON). """
        
        self.description = None
        """ Human language description of the value set.
        Type `str`. """
        
        self.expansion = None
        """ Used when the value set is "expanded".
        Type `ValueSetExpansion` (represented as `dict` in JSON). """
        
        self.experimental = None
        """ If for testing purposes, not real usage.
        Type `bool`. """
        
        self.extensible = None
        """ Whether this is intended to be used with an extensible binding.
        Type `bool`. """
        
        self.identifier = None
        """ Additional identifier for the value set (v2 / CDA).
        Type `Identifier` (represented as `dict` in JSON). """
        
        self.immutable = None
        """ Indicates whether or not any change to the content logical
        definition may occur.
        Type `bool`. """
        
        self.lockedDate = None
        """ Fixed date for all referenced code systems and value sets.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.name = None
        """ Informal name for this value set.
        Type `str`. """
        
        self.publisher = None
        """ Name of the publisher (Organization or individual).
        Type `str`. """
        
        self.requirements = None
        """ Why is this needed?.
        Type `str`. """
        
        self.status = None
        """ draft | active | retired.
        Type `str`. """
        
        self.url = None
        """ Globally unique logical id for  value set.
        Type `str`. """
        
        self.useContext = None
        """ Content intends to support these contexts.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.version = None
        """ Logical id for this version of the value set.
        Type `str`. """
        
        super(ValueSet, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSet, self).elementProperties()
        js.extend([
            ("compose", "compose", ValueSetCompose, False),
            ("contact", "contact", ValueSetContact, True),
            ("copyright", "copyright", str, False),
            ("date", "date", fhirdate.FHIRDate, False),
            ("define", "define", ValueSetDefine, False),
            ("description", "description", str, False),
            ("expansion", "expansion", ValueSetExpansion, False),
            ("experimental", "experimental", bool, False),
            ("extensible", "extensible", bool, False),
            ("identifier", "identifier", identifier.Identifier, False),
            ("immutable", "immutable", bool, False),
            ("lockedDate", "lockedDate", fhirdate.FHIRDate, False),
            ("name", "name", str, False),
            ("publisher", "publisher", str, False),
            ("requirements", "requirements", str, False),
            ("status", "status", str, False),
            ("url", "url", str, False),
            ("useContext", "useContext", codeableconcept.CodeableConcept, True),
            ("version", "version", str, False),
        ])
        return js


class ValueSetCompose(fhirelement.FHIRElement):
    """ When value set includes codes from elsewhere.
    """
    
    resource_name = "ValueSetCompose"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.exclude = None
        """ Explicitly exclude codes.
        List of `ValueSetComposeInclude` items (represented as `dict` in JSON). """
        
        self.importFrom = None
        """ Import the contents of another value set.
        List of `str` items. """
        
        self.include = None
        """ Include one or more codes from a code system.
        List of `ValueSetComposeInclude` items (represented as `dict` in JSON). """
        
        super(ValueSetCompose, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSetCompose, self).elementProperties()
        js.extend([
            ("exclude", "exclude", ValueSetComposeInclude, True),
            ("importFrom", "import", str, True),
            ("include", "include", ValueSetComposeInclude, True),
        ])
        return js


class ValueSetComposeInclude(fhirelement.FHIRElement):
    """ Include one or more codes from a code system.
    """
    
    resource_name = "ValueSetComposeInclude"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.concept = None
        """ A concept defined in the system.
        List of `ValueSetComposeIncludeConcept` items (represented as `dict` in JSON). """
        
        self.filter = None
        """ Select codes/concepts by their properties (including relationships).
        List of `ValueSetComposeIncludeFilter` items (represented as `dict` in JSON). """
        
        self.system = None
        """ The system the codes come from.
        Type `str`. """
        
        self.version = None
        """ Specific version of the code system referred to.
        Type `str`. """
        
        super(ValueSetComposeInclude, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSetComposeInclude, self).elementProperties()
        js.extend([
            ("concept", "concept", ValueSetComposeIncludeConcept, True),
            ("filter", "filter", ValueSetComposeIncludeFilter, True),
            ("system", "system", str, False),
            ("version", "version", str, False),
        ])
        return js


class ValueSetComposeIncludeConcept(fhirelement.FHIRElement):
    """ A concept defined in the system.
    
    Specifies a concept to be included or excluded.
    """
    
    resource_name = "ValueSetComposeIncludeConcept"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.code = None
        """ Code or expression from system.
        Type `str`. """
        
        self.designation = None
        """ Additional representations for this valueset.
        List of `ValueSetDefineConceptDesignation` items (represented as `dict` in JSON). """
        
        self.display = None
        """ Test to display for this code for this value set.
        Type `str`. """
        
        super(ValueSetComposeIncludeConcept, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSetComposeIncludeConcept, self).elementProperties()
        js.extend([
            ("code", "code", str, False),
            ("designation", "designation", ValueSetDefineConceptDesignation, True),
            ("display", "display", str, False),
        ])
        return js


class ValueSetComposeIncludeFilter(fhirelement.FHIRElement):
    """ Select codes/concepts by their properties (including relationships).
    
    Select concepts by specify a matching criteria based on the properties
    (including relationships) defined by the system. If multiple filters are
    specified, they SHALL all be true.
    """
    
    resource_name = "ValueSetComposeIncludeFilter"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.op = None
        """ = | is-a | is-not-a | regex | in | not-in.
        Type `str`. """
        
        self.property = None
        """ A property defined by the code system.
        Type `str`. """
        
        self.value = None
        """ Code from the system, or regex criteria.
        Type `str`. """
        
        super(ValueSetComposeIncludeFilter, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSetComposeIncludeFilter, self).elementProperties()
        js.extend([
            ("op", "op", str, False),
            ("property", "property", str, False),
            ("value", "value", str, False),
        ])
        return js


class ValueSetContact(fhirelement.FHIRElement):
    """ Contact details of the publisher.
    
    Contacts to assist a user in finding and communicating with the publisher.
    """
    
    resource_name = "ValueSetContact"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.name = None
        """ Name of a individual to contact.
        Type `str`. """
        
        self.telecom = None
        """ Contact details for individual or publisher.
        List of `ContactPoint` items (represented as `dict` in JSON). """
        
        super(ValueSetContact, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSetContact, self).elementProperties()
        js.extend([
            ("name", "name", str, False),
            ("telecom", "telecom", contactpoint.ContactPoint, True),
        ])
        return js


class ValueSetDefine(fhirelement.FHIRElement):
    """ When value set defines its own codes.
    
    A definition of an code system, inlined into the value set.
    """
    
    resource_name = "ValueSetDefine"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.caseSensitive = None
        """ If code comparison is case sensitive.
        Type `bool`. """
        
        self.concept = None
        """ Concepts in the code system.
        List of `ValueSetDefineConcept` items (represented as `dict` in JSON). """
        
        self.system = None
        """ URI to identify the code system.
        Type `str`. """
        
        self.version = None
        """ Version of this system.
        Type `str`. """
        
        super(ValueSetDefine, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSetDefine, self).elementProperties()
        js.extend([
            ("caseSensitive", "caseSensitive", bool, False),
            ("concept", "concept", ValueSetDefineConcept, True),
            ("system", "system", str, False),
            ("version", "version", str, False),
        ])
        return js


class ValueSetDefineConcept(fhirelement.FHIRElement):
    """ Concepts in the code system.
    """
    
    resource_name = "ValueSetDefineConcept"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.abstract = None
        """ If this code is not for use as a real concept.
        Type `bool`. """
        
        self.code = None
        """ Code that identifies concept.
        Type `str`. """
        
        self.concept = None
        """ Child Concepts (is-a / contains).
        List of `ValueSetDefineConcept` items (represented as `dict` in JSON). """
        
        self.definition = None
        """ Formal Definition.
        Type `str`. """
        
        self.designation = None
        """ Additional representations for the concept.
        List of `ValueSetDefineConceptDesignation` items (represented as `dict` in JSON). """
        
        self.display = None
        """ Text to Display to the user.
        Type `str`. """
        
        super(ValueSetDefineConcept, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSetDefineConcept, self).elementProperties()
        js.extend([
            ("abstract", "abstract", bool, False),
            ("code", "code", str, False),
            ("concept", "concept", ValueSetDefineConcept, True),
            ("definition", "definition", str, False),
            ("designation", "designation", ValueSetDefineConceptDesignation, True),
            ("display", "display", str, False),
        ])
        return js


class ValueSetDefineConceptDesignation(fhirelement.FHIRElement):
    """ Additional representations for the concept.
    
    Additional representations for the concept - other languages, aliases,
    specialised purposes, used for particular purposes, etc.
    """
    
    resource_name = "ValueSetDefineConceptDesignation"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.language = None
        """ Language of the designation.
        Type `str`. """
        
        self.use = None
        """ Details how this designation would be used.
        Type `Coding` (represented as `dict` in JSON). """
        
        self.value = None
        """ The text value for this designation.
        Type `str`. """
        
        super(ValueSetDefineConceptDesignation, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSetDefineConceptDesignation, self).elementProperties()
        js.extend([
            ("language", "language", str, False),
            ("use", "use", coding.Coding, False),
            ("value", "value", str, False),
        ])
        return js


class ValueSetExpansion(fhirelement.FHIRElement):
    """ Used when the value set is "expanded".
    
    A value set can also be "expanded", where the value set is turned into a
    simple collection of enumerated codes. This element holds the expansion, if
    it has been performed.
    """
    
    resource_name = "ValueSetExpansion"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.contains = None
        """ Codes in the value set.
        List of `ValueSetExpansionContains` items (represented as `dict` in JSON). """
        
        self.identifier = None
        """ Uniquely identifies this expansion.
        Type `str`. """
        
        self.parameter = None
        """ Parameter that controlled the expansion process.
        List of `ValueSetExpansionParameter` items (represented as `dict` in JSON). """
        
        self.timestamp = None
        """ Time valueset expansion happened.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        super(ValueSetExpansion, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSetExpansion, self).elementProperties()
        js.extend([
            ("contains", "contains", ValueSetExpansionContains, True),
            ("identifier", "identifier", str, False),
            ("parameter", "parameter", ValueSetExpansionParameter, True),
            ("timestamp", "timestamp", fhirdate.FHIRDate, False),
        ])
        return js


class ValueSetExpansionContains(fhirelement.FHIRElement):
    """ Codes in the value set.
    
    The codes that are contained in the value set expansion.
    """
    
    resource_name = "ValueSetExpansionContains"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.abstract = None
        """ If user cannot select this entry.
        Type `bool`. """
        
        self.code = None
        """ Code - if blank, this is not a choosable code.
        Type `str`. """
        
        self.contains = None
        """ Codes contained in this concept.
        List of `ValueSetExpansionContains` items (represented as `dict` in JSON). """
        
        self.display = None
        """ User display for the concept.
        Type `str`. """
        
        self.system = None
        """ System value for the code.
        Type `str`. """
        
        self.version = None
        """ Version in which this code / display is defined.
        Type `str`. """
        
        super(ValueSetExpansionContains, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSetExpansionContains, self).elementProperties()
        js.extend([
            ("abstract", "abstract", bool, False),
            ("code", "code", str, False),
            ("contains", "contains", ValueSetExpansionContains, True),
            ("display", "display", str, False),
            ("system", "system", str, False),
            ("version", "version", str, False),
        ])
        return js


class ValueSetExpansionParameter(fhirelement.FHIRElement):
    """ Parameter that controlled the expansion process.
    
    A Parameter that controlled the expansion process. These paameters may be
    used by users of expanded value sets to check whether the expansion is
    suitable for a particular purpose, or to pick the correct expansion.
    """
    
    resource_name = "ValueSetExpansionParameter"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.name = None
        """ Name as assigned by server.
        Type `str`. """
        
        self.valueBoolean = None
        """ Value of the parameter.
        Type `bool`. """
        
        self.valueCode = None
        """ Value of the parameter.
        Type `str`. """
        
        self.valueDecimal = None
        """ Value of the parameter.
        Type `float`. """
        
        self.valueInteger = None
        """ Value of the parameter.
        Type `int`. """
        
        self.valueString = None
        """ Value of the parameter.
        Type `str`. """
        
        self.valueUri = None
        """ Value of the parameter.
        Type `str`. """
        
        super(ValueSetExpansionParameter, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(ValueSetExpansionParameter, self).elementProperties()
        js.extend([
            ("name", "name", str, False),
            ("valueBoolean", "valueBoolean", bool, False),
            ("valueCode", "valueCode", str, False),
            ("valueDecimal", "valueDecimal", float, False),
            ("valueInteger", "valueInteger", int, False),
            ("valueString", "valueString", str, False),
            ("valueUri", "valueUri", str, False),
        ])
        return js




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 0.5.0.5149 (http://hl7.org/fhir/StructureDefinition/Signature) on 2015-07-06.
#  2015, SMART Health IT.


from . import coding
from . import fhirdate
from . import fhirelement
from . import fhirreference


class Signature(fhirelement.FHIRElement):
    """ An XML digital Signature.
    
    An XML digital signature along with supporting context.
    """
    
    resource_name = "Signature"
    
    def __init__(self, jsondict=None):
        """ Initialize all valid properties.
        """
        
        self.blob = None
        """ The actual XML Dig-Sig.
        Type `str`. """
        
        self.type = None
        """ Indication of the reason the entity signed the object(s).
        List of `Coding` items (represented as `dict` in JSON). """
        
        self.when = None
        """ When the signature was created.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.whoReference = None
        """ Who signed the signature.
        Type `FHIRReference` referencing `Practitioner, RelatedPerson, Patient` (represented as `dict` in JSON). """
        
        self.whoUri = None
        """ Who signed the signature.
        Type `str`. """
        
        super(Signature, self).__init__(jsondict)
    
    def elementProperties(self):
        js = super(Signature, self).elementProperties()
        js.extend([
            ("blob", "blob", str, False),
            ("type", "type", coding.Coding, True),
            ("when", "when", fhirdate.FHIRDate, False),
            ("whoReference", "whoReference", fhirreference.FHIRReference, False),
            ("whoUri", "whoUri", str, False),
        ])
        return js

